
##########################################################
# Dear PyGui User Interface
#   ~ Version: master
#
#   Notes:
#     * This file is automatically generated.
#
#   Resources:
#     * FAQ:         https://github.com/hoffstadt/DearPyGui/discussions/categories/frequently-asked-questions-faq 
#     * Homepage:    https://github.com/hoffstadt/DearPyGui 
#     * Wiki:        https://github.com/hoffstadt/DearPyGui/wiki 
#     * Issues:      https://github.com/hoffstadt/DearPyGui/issues
#     * Discussions: https://github.com/hoffstadt/DearPyGui/discussions
##########################################################

from typing import List, Any, Callable, Union, Tuple
from contextlib import contextmanager
import dearpygui._dearpygui as internal_dpg
from dearpygui._dearpygui import mvBuffer

########################################################################################################################
# User API Index
#
#    * Sections
#      - Helper Commands
#      - Tool Commands
#      - Information Commands
#      - Configuration Getter Commands
#      - Configuration Setter Commands
#      - State Commands
#      - Viewport Setter Commands
#      - Viewport Getter Commands
#      - Container Context Managers
#      - Core Wrappings
#      - Constants
#
########################################################################################################################

########################################################################################################################
# Helper Commands
########################################################################################################################

def configure_item(item : Union[int, str], **kwargs) -> None:
	"""Configures an item after creation."""
	internal_dpg.configure_item(item, **kwargs)


def configure_viewport(item : Union[int, str], **kwargs) -> None:
	"""Configures a viewport after creation."""
	internal_dpg.configure_viewport(item, **kwargs)


def setup_registries() -> None:
    """Adds default registries for fonts, handlers, textures, colormaps, and values."""
    internal_dpg.add_font_registry(id=internal_dpg.mvReservedUUID_0)
    internal_dpg.add_handler_registry(id=internal_dpg.mvReservedUUID_1)
    internal_dpg.add_texture_registry(id=internal_dpg.mvReservedUUID_2)
    internal_dpg.add_value_registry(id=internal_dpg.mvReservedUUID_3)
    internal_dpg.add_colormap_registry(id=internal_dpg.mvReservedUUID_4)


def setup_viewport():
    """Prepares viewport. If not called, start_dearpygui will automatically call this.

    Returns:
        None
    """
    vp = internal_dpg.create_viewport()
    internal_dpg.setup_dearpygui(viewport=vp)
    internal_dpg.show_viewport(vp)


def start_dearpygui():
    """Prepares viewport (if not done already). sets up, cleans up, and runs main event loop.

    Returns:
        None
    """

    if not internal_dpg.is_viewport_created():
        setup_viewport()

    while(internal_dpg.is_dearpygui_running()):
        internal_dpg.render_dearpygui_frame()   
    internal_dpg.cleanup_dearpygui()


@contextmanager
def mutex():
   
   try:
        yield internal_dpg.lock_mutex()
   finally:
        internal_dpg.unlock_mutex()


@contextmanager
def popup(parent: Union[int, str], mousebutton: int = internal_dpg.mvMouseButton_Right, modal: bool = False) -> int:
    
    try:
        _internal_popup_id = internal_dpg.generate_uuid()
        internal_dpg.add_clicked_handler(parent, mousebutton, callback=lambda: internal_dpg.configure_item(_internal_popup_id, show=True))
        if modal:
            internal_dpg.add_window(modal=True, show=False, id=_internal_popup_id, autosize=True)
        else:
            internal_dpg.add_window(popup=True, show=False, id=_internal_popup_id, autosize=True)
        internal_dpg.push_container_stack(internal_dpg.last_container())
        yield _internal_popup_id

    finally:
        internal_dpg.pop_container_stack()


########################################################################################################################
# Tool Commands
########################################################################################################################

def show_style_editor() -> None:
    """Shows the standard style editor window

    Returns:
        None
    """
    internal_dpg.show_tool(internal_dpg.mvTool_Style)


def show_metrics() -> None:
    """Shows the standard metrics window

    Returns:
        None
    """
    internal_dpg.show_tool(internal_dpg.mvTool_Metrics)


def show_about() -> None:
    """Shows the standard about window

    Returns:
        None
    """
    internal_dpg.show_tool(internal_dpg.mvTool_About)


def show_debug() -> None:
    """Shows the standard debug window

    Returns:
        None
    """
    internal_dpg.show_tool(internal_dpg.mvTool_Debug)


def show_documentation() -> None:
    """Shows the standard documentation window

    Returns:
        None
    """
    internal_dpg.show_tool(internal_dpg.mvTool_Doc)


def show_font_manager() -> None:
    """Shows the standard documentation window

    Returns:
        None
    """
    internal_dpg.show_tool(internal_dpg.mvTool_Font)


def show_item_registry() -> None:
    """Shows the standard documentation window

    Returns:
        None
    """
    internal_dpg.show_tool(internal_dpg.mvTool_ItemRegistry)


########################################################################################################################
# Information Commands
########################################################################################################################

def get_item_slot(item: Union[int, str]) -> Union[int, None]:
    """Returns an item's target slot.

    Returns:
        slot as a int
    """
    return internal_dpg.get_item_info(item)["target"]

def is_item_container(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is a container.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_info(item)["container"]


def get_item_parent(item: Union[int, str]) -> Union[int, None]:
    """Gets the item's parent.

    Returns:
        parent as a int or None
    """
    return internal_dpg.get_item_info(item)["parent"]


def get_item_children(item: Union[int, str] , slot: int = -1) -> Union[List[int], None]:
    """Provides access to the item's children slots.

    Returns:
        A 2-D tuple of children slots ex. ((child_slot_1),(child_slot_2),(child_slot_3),...) or a single slot if slot is used.
    """
    if slot < 0 or slot > 4:
        return internal_dpg.get_item_info(item)["children"]
    return internal_dpg.get_item_info(item)["children"][slot]


def get_item_type(item: Union[int, str]) -> Union[str]:
    """Gets the item's type.

    Returns:
        type as a string or None
    """
    return internal_dpg.get_item_info(item)["type"]


def get_item_theme(item: Union[int, str]) -> int:
    """Gets the item's theme.

    Returns:
        theme's uuid
    """
    return internal_dpg.get_item_info(item)["theme"]


def get_item_font(item: Union[int, str]) -> int:
    """Gets the item's font.

    Returns:
        font's uuid
    """
    return internal_dpg.get_item_info(item)["font"]


def get_item_disabled_theme(item: Union[int, str]) -> int:
    """Gets the item's disabled theme.

    Returns:
        theme's uuid
    """
    return internal_dpg.get_item_info(item)["disabled_theme"]


########################################################################################################################
# Configuration Setter Commands
########################################################################################################################

def enable_item(item: Union[int, str]):
    """Enables the item.

    Args:
        **item: Item to enable.

    Returns:
        None
    """
    internal_dpg.configure_item(item, enabled=True)


def disable_item(item: Union[int, str]):
    """Disables the item.

    Args:
        **item: Item to disable.

    Returns:
        None
    """
    internal_dpg.configure_item(item, enabled=False)


def set_item_label(item: Union[int, str], label: str):
    """Sets the item's displayed label, anything after the characters "##" in the name will not be shown.

    Args:
        item: Item label will be applied to.
        label: Displayed name to be applied.

    Returns:
        None
    """
    internal_dpg.configure_item(item, label=label)


def set_item_source(item: Union[int, str], source: Union[int, str]):
    """Sets the item's value, to the source's value. Widget's value will now be "linked" to source's value.

    Args:
        item: Item to me linked.
        source: Source to link to.

    Returns:
        None
    """
    internal_dpg.configure_item(item, source=source)


def set_item_pos(item: Union[int, str], pos: List[float]):
    """Sets the item's position.

    Args:
        item: Item the absolute position will be applied to.
        pos: X and Y positions relative to parent of the item.

    Returns:
        None
    """
    internal_dpg.configure_item(item, pos=pos)


def set_item_width(item: Union[int, str], width: int):
    """Sets the item's width.

    Args:
        item: Item the Width will be applied to.
        width: Width to be applied.

    Returns:
        None
    """
    internal_dpg.configure_item(item, width=width)


def set_item_height(item: Union[int, str], height: int):
    """Sets the item's height.

    Args:
        item: Item the Height will be applied to.
        height: Height to be applied.

    Returns:
        None
    """
    internal_dpg.configure_item(item, height=height)


def set_item_indent(item: Union[int, str], indent: int):
    """Sets the item's indent.

    Args:
        item: Item the Height will be applied to.
        height: Height to be applied.

    Returns:
        None
    """
    internal_dpg.configure_item(item, indent=indent)


def set_item_track_offset(item: Union[int, str], offset: float):
    """Sets the item's track offset.

    Args:
        item: Item the Height will be applied to.
        height: Height to be applied.

    Returns:
        None
    """
    internal_dpg.configure_item(item, track_offset=offset)


def set_item_payload_type(item: Union[int, str], payload_type: str):
    """Sets the item's payload type.

    Args:
        item: Item the Height will be applied to.
        height: Height to be applied.

    Returns:
        None
    """
    internal_dpg.configure_item(item, payload_type=str)


def set_item_callback(item: Union[int, str], callback: Callable):
    """Sets the item's callack.

    Args:
        item: Item the callback will be applied to.
        callback: Callback to be applied.

    Returns:
        None
    """
    internal_dpg.configure_item(item, callback=callback)


def set_item_drag_callback(item: Union[int, str], callback: Callable):
    """Sets the item's drag callack.

    Args:
        item: Item the callback will be applied to.
        callback: Callback to be applied.

    Returns:
        None
    """
    internal_dpg.configure_item(item, drag_callback=callback)


def set_item_drop_callback(item: Union[int, str], callback: Callable):
    """Sets the item's drop callack.

    Args:
        item: Item the callback will be applied to.
        callback: Callback to be applied.

    Returns:
        None
    """
    internal_dpg.configure_item(item, drop_callback=callback)


def track_item(item: Union[int, str]):
    """Track item in scroll region.

    Args:
        item: Item the callback will be applied to.
        callback: Callback to be applied.

    Returns:
        None
    """
    internal_dpg.configure_item(item, tracked=True)


def untrack_item(item: Union[int, str]):
    """Track item in scroll region.

    Args:
        item: Item the callback will be applied to.
        callback: Callback to be applied.

    Returns:
        None
    """
    internal_dpg.configure_item(item, tracked=False)


def set_item_user_data(item: Union[int, str], user_data: Any):
    """Sets the item's callack_data to any python object.

    Args:
        item: Item the callback will be applied to.
        user_data: Callback_data to be applied.

    Returns:
        None
    """
    internal_dpg.configure_item(item, user_data=user_data)


def show_item(item: Union[int, str]):
    """Shows the item.

    Args:
        item: Item to show.

    Returns:
        None
    """
    internal_dpg.configure_item(item, show=True)


def hide_item(item: Union[int, str], *, children_only: bool = False):
    """Hides the item.

    Args:
        **item: Item to hide.

    Returns:
        None
    """
    if children_only:
        children = get_item_children(item)
        for child in children:
            internal_dpg.configure_item(child, show=False)
    else:
        internal_dpg.configure_item(item, show=False)


########################################################################################################################
# Configuration Getter Commands
########################################################################################################################

def get_item_label(item: Union[int, str]) -> Union[str, None]:
    """Gets the item's label.

    Returns:
        label as a string or None
    """
    return internal_dpg.get_item_configuration(item)["label"]


def get_item_filter_key(item: Union[int, str]) -> Union[str, None]:
    """Gets the item's filter key.

    Returns:
        filter key as a string or None
    """
    return internal_dpg.get_item_configuration(item)["filter_key"]


def is_item_tracked(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is tracked.

    Returns:
        tracked as a bool or None
    """
    return internal_dpg.get_item_configuration(item)["tracked"]


def is_item_search_delayed(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is search delayed.

    Returns:
        tracked as a bool or None
    """
    return internal_dpg.get_item_configuration(item)["delay_search"]


def get_item_indent(item: Union[int, str]) -> Union[int, None]:
    """Gets the item's indent.

    Returns:
        indent as a int or None
    """
    return internal_dpg.get_item_configuration(item)["indent"]


def get_item_track_offset(item: Union[int, str]) -> Union[float, None]:
    """Gets the item's track offset.

    Returns:
        track offset as a int or None
    """
    return internal_dpg.get_item_configuration(item)["track_offset"]


def get_item_width(item: Union[int, str]) -> Union[int, None]:
    """Gets the item's width.

    Returns:
        width as a int or None
    """
    return internal_dpg.get_item_configuration(item)["width"]


def get_item_height(item: Union[int, str]) -> Union[int, None]:
    """Gets the item's height.

    Returns:
        height as a int or None
    """
    return internal_dpg.get_item_configuration(item)["height"]


def get_item_callback(item: Union[int, str]) -> Union[str, None]:
    """Gets the item's callback.

    Returns:
        callback as a string or None
    """
    return internal_dpg.get_item_configuration(item)["callback"]


def get_item_drag_callback(item: Union[int, str]) -> Union[str, None]:
    """Gets the item's drag callback.

    Returns:
        callback as a string or None
    """
    return internal_dpg.get_item_configuration(item)["drag_callback"]


def get_item_drop_callback(item: Union[int, str]) -> Union[str, None]:
    """Gets the item's drop callback.

    Returns:
        callback as a string or None
    """
    return internal_dpg.get_item_configuration(item)["drop_callback"]


def get_item_user_data(item: Union[int, str]) -> Union[Any, None]:
    """Gets the item's callback data.

    Returns:
        callback data as a python object or None
    """
    return internal_dpg.get_item_configuration(item)["user_data"]


def get_item_source(item: Union[int, str]) -> Union[str, None]:
    """Gets the item's source.

    Returns:
        source as a string or None
    """
    return internal_dpg.get_item_configuration(item)["source"]


########################################################################################################################
# State Commands
########################################################################################################################

def is_item_hovered(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is hovered.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["hovered"]


def is_item_active(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is active.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["active"]


def is_item_focused(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is focused.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["focused"]


def is_item_clicked(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is clicked.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["clicked"]


def is_item_left_clicked(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is left clicked.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["left_clicked"]


def is_item_right_clicked(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is right clicked.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["right_clicked"]


def is_item_middle_clicked(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is middle clicked.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["middle_clicked"]


def is_item_visible(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is visible.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["visible"]


def is_item_edited(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is edited.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["edited"]


def is_item_activated(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is activated.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["activated"]


def is_item_deactivated(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is deactivated.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["deactivated"]


def is_item_deactivated_after_edit(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is deactivated_after_edit.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["deactivated_after_edit"]


def is_item_toggled_open(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is toggled_open.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["toggled_open"]


def is_item_ok(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is ok and can be used.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_state(item)["ok"]


def is_item_shown(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is shown.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_configuration(item)["show"]


def is_item_enabled(item: Union[int, str]) -> Union[bool, None]:
    """Checks if item is enabled.

    Returns:
        status as a bool
    """
    return internal_dpg.get_item_configuration(item)["enabled"]


def get_item_pos(item: Union[int, str]) -> List[int]:
    """Returns item's position.

    Returns:
        position
    """
    return internal_dpg.get_item_state(item)["pos"]


def get_available_content_region(item: Union[int, str]) -> List[int]:
    """Returns item's available content region.

    Returns:
        position
    """
    return internal_dpg.get_item_state(item)["content_region_avail"]


def get_item_rect_size(item: Union[int, str]) -> List[int]:
    """Returns item's available content region.

    Returns:
        position
    """
    return internal_dpg.get_item_state(item)["rect_size"]


def get_item_rect_min(item: Union[int, str]) -> List[int]:
    """Returns item's minimum content region.

    Returns:
        position
    """
    return internal_dpg.get_item_state(item)["rect_min"]


def get_item_rect_max(item: Union[int, str]) -> List[int]:
    """Returns item's maximum content region.

    Returns:
        position
    """
    return internal_dpg.get_item_state(item)["rect_max"]


########################################################################################################################
# Viewport Setter Commands
########################################################################################################################

def set_viewport_clear_color(color: List[int]):
    """Sets the viewport's clear color.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, clear_color=color)


def set_viewport_small_icon(icon: str):
    """Sets the viewport's small icon. Must be ico for windows.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, small_icon=icon)


def set_viewport_large_icon(icon: str):
    """Sets the viewport's small icon. Must be ico for windows.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, large_icon=icon)


def set_viewport_pos(pos: List[float]):
    """Sets the viewport's position.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, x_pos=pos[0], y_pos=pos[1])


def set_viewport_width(width: int):
    """Sets the viewport's width.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, width=width)


def set_viewport_height(height: int):
    """Sets the viewport's height.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, height=height)


def set_viewport_min_width(width: int):
    """Sets the viewport's minimum width.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, min_width=width)


def set_viewport_max_width(width: int):
    """Sets the viewport's max width.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, max_width=width)


def set_viewport_min_height(height: int):
    """Sets the viewport's minimum height.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, min_height=height)


def set_viewport_max_height(height: int):
    """Sets the viewport's max width.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, max_height=height)


def set_viewport_title(title: str):
    """Sets the viewport's title.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, title=title)


def set_viewport_always_top(value: bool):
    """Sets the viewport always on top.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, always_on_top=value)


def set_viewport_resizable(value: bool):
    """Sets the viewport resizable.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, resizable=value)

def set_viewport_vsync(value: bool):
    """Sets the viewport vsync.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, vsync=value)


def set_viewport_decorated(value: bool):
    """Sets the viewport to be decorated.

    Returns:
        None
    """
    internal_dpg.configure_viewport(0, decorated=value)

########################################################################################################################
# Viewport Getter Commands
########################################################################################################################

def get_viewport_clear_color() ->List[int]:
    """Gets the viewport's clear color.

    Returns:
        List[int]
    """
    return internal_dpg.get_viewport_configuration()["clear_color"]


def get_viewport_pos() ->List[float]:
    """Gets the viewport's position.

    Returns:
        viewport position.
    """
    config = internal_dpg.get_viewport_configuration()
    x_pos = config["x_pos"]
    y_pos = config["y_pos"]
    return [x_pos, y_pos]


def get_viewport_width() -> int:
    """Gets the viewport's width.

    Returns:
        viewport width
    """
    return internal_dpg.get_viewport_configuration()["width"]


def get_viewport_client_width() -> int:
    """Gets the viewport's client width.

    Returns:
        viewport width
    """
    return internal_dpg.get_viewport_configuration()["client_width"]


def get_viewport_client_height() -> int:
    """Gets the viewport's client height.

    Returns:
        viewport width
    """
    return internal_dpg.get_viewport_configuration()["client_height"]


def get_viewport_height() -> int:
    """Gets the viewport's height.

    Returns:
        int
    """
    return internal_dpg.get_viewport_configuration()["height"]


def get_viewport_min_width() -> int:
    """Gets the viewport's minimum width.

    Returns:
        int
    """
    return internal_dpg.get_viewport_configuration()["min_width"]


def get_viewport_max_width() -> int:
    """Gets the viewport's max width.

    Returns:
        int
    """
    return internal_dpg.get_viewport_configuration()["max_width"]


def get_viewport_min_height() -> int:
    """Gets the viewport's minimum height.

    Returns:
        int
    """
    return internal_dpg.get_viewport_configuration()["min_height"]


def get_viewport_max_height() -> int:
    """Gets the viewport's max width.

    Returns:
        int
    """
    return internal_dpg.get_viewport_configuration()["max_height"]


def get_viewport_title() -> str:
    """Gets the viewport's title.

    Returns:
        str
    """
    return internal_dpg.get_viewport_configuration()["title"]


def is_viewport_always_top() -> bool:
    """Checks the viewport always on top flag.

    Returns:
        bool
    """
    return internal_dpg.get_viewport_configuration()["always_on_top"]


def is_viewport_resizable() -> bool:
    """Checks the viewport resizable flag.

    Returns:
        bool
    """
    return internal_dpg.get_viewport_configuration()["resizable"]


def is_viewport_vsync_on() -> bool:
    """Checks the viewport vsync flag.

    Returns:
        bool
    """
    return internal_dpg.get_viewport_configuration()["vsync"]


def is_viewport_decorated() -> bool:
    """Checks if the viewport is docorated.

    Returns:
        bool
    """
    return internal_dpg.get_viewport_configuration()["decorated"]

##########################################################
# Container Context Managers
##########################################################

@contextmanager
def child(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, border: bool =True, autosize_x: bool =False, autosize_y: bool =False, no_scrollbar: bool =False, horizontal_scrollbar: bool =False, menubar: bool =False) -> Union[int, str]:
	"""
	Adds an embedded child window. Will show scrollbars when items do not fit. Must be followed by a call to end.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**border (bool): Shows/Hides the border around the sides.
		**autosize_x (bool): Autosize the window to fit it's items in the x.
		**autosize_y (bool): Autosize the window to fit it's items in the y.
		**no_scrollbar (bool):  Disable scrollbars (window can still scroll with mouse or programmatically).
		**horizontal_scrollbar (bool): Allow horizontal scrollbar to appear (off by default).
		**menubar (bool): Shows/Hides the menubar at the top.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_child(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, border=border, autosize_x=autosize_x, autosize_y=autosize_y, no_scrollbar=no_scrollbar, horizontal_scrollbar=horizontal_scrollbar, menubar=menubar)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def clipper(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, delay_search: bool =False) -> Union[int, str]:
	"""
	Helper to manually clip large list of items. Increases performance by not searching or drawing widgets outside of the clipped region.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_clipper(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, show=show, delay_search=delay_search)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def collapsing_header(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, closable: bool =False, default_open: bool =False, open_on_double_click: bool =False, open_on_arrow: bool =False, leaf: bool =False, bullet: bool =False) -> Union[int, str]:
	"""
	Adds a collapsing header to add items to. Must be closed with the end command.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**closable (bool): Adds the ability to hide this widget by pressing the (x) in the top right of widget.
		**default_open (bool): Sets the collapseable header open by default.
		**open_on_double_click (bool): Need double-click to open node.
		**open_on_arrow (bool): Only open when clicking on the arrow part.
		**leaf (bool): No collapsing, no arrow (use as a convenience for leaf nodes).
		**bullet (bool): Display a bullet instead of arrow.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_collapsing_header(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, closable=closable, default_open=default_open, open_on_double_click=open_on_double_click, open_on_arrow=open_on_arrow, leaf=leaf, bullet=bullet)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def colormap_registry(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, show: bool =False) -> Union[int, str]:
	"""
	Adds a colormap registry.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**show (bool): Attempt to render widget.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_colormap_registry(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, show=show)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def drag_payload(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, show: bool =True, drag_data: Any =None, payload_type: str ='$$DPG_PAYLOAD') -> Union[int, str]:
	"""
	User data payload for drag and drop operations.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**show (bool): Attempt to render widget.
		**drag_data (Any): Drag data
		**payload_type (str): 
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_drag_payload(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, show=show, drag_data=drag_data, payload_type=payload_type)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def draw_layer(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Creates a layer that can be drawn to. Useful for grouping drawing items.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_draw_layer(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def drawlist(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5) -> Union[int, str]:
	"""
	A container widget that is used to present draw items or layers. Layers and draw items should be added to this widget as children.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_drawlist(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def file_dialog(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, callback: Callable =None, show: bool =True, default_path: str ='', default_filename: str ='.', file_count: int =0, modal: bool =False, directory_selector: bool =False) -> Union[int, str]:
	"""
	Displays a file or directory selector depending on keywords. Displays a file dialog by default.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**default_path (str): Path that the file dialog will default to when opened.
		**default_filename (str): Default name that will show in the file name input.
		**file_count (int): Number of visible files in the dialog.
		**modal (bool): Forces user interaction with the file selector.
		**directory_selector (bool): Shows only directory/paths as options. Allows selection of directory/paths only.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_file_dialog(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, callback=callback, show=show, default_path=default_path, default_filename=default_filename, file_count=file_count, modal=modal, directory_selector=directory_selector)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def filter_set(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, delay_search: bool =False) -> Union[int, str]:
	"""
	Helper to parse and apply text filters (e.g. aaaaa[, bbbbb][, ccccc])
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_filter_set(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, show=show, delay_search=delay_search)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def font(file : str, size : int, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, default_font: bool =False, parent: Union[int, str] =internal_dpg.mvReservedUUID_0) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		file (str): 
		size (int): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**default_font (bool): 
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_font(file, size, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, default_font=default_font, parent=parent)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def font_registry(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**show (bool): Attempt to render widget.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_font_registry(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, show=show)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def group(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, horizontal: bool =False, horizontal_spacing: float =-1) -> Union[int, str]:
	"""
	Creates a group that other widgets can belong to. The group allows item commands to be issued for all of its members. Must be closed with the end command.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**horizontal (bool): Forces child widgets to be added in a horizontal layout.
		**horizontal_spacing (float): Spacing for the horizontal layout.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_group(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, horizontal=horizontal, horizontal_spacing=horizontal_spacing)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def handler_registry(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Adds a handler registry.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**show (bool): Attempt to render widget.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_handler_registry(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, show=show)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def menu(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5) -> Union[int, str]:
	"""
	Adds a menu to an existing menu bar. Must be followed by a call to end.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_menu(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def menu_bar(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, show: bool =True, delay_search: bool =False) -> Union[int, str]:
	"""
	Adds a menu bar to a window.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**show (bool): Attempt to render widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_menu_bar(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, show=show, delay_search=delay_search)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def node(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, draggable: bool =True) -> Union[int, str]:
	"""
	Adds a node to a node editor.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**draggable (bool): Allow node to be draggable.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_node(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, draggable=draggable)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def node_attribute(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, filter_key: str ='', tracked: bool =False, track_offset: float =0.5, attribute_type: int =0, shape: int =1, category: str ='general') -> Union[int, str]:
	"""
	Adds a node attribute.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**attribute_type (int): mvNode_Attr_Input, mvNode_Attr_Output, or mvNode_Attr_Static.
		**shape (int): Pin shape.
		**category (str): Category
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_node_attribute(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, filter_key=filter_key, tracked=tracked, track_offset=track_offset, attribute_type=attribute_type, shape=shape, category=category)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def node_editor(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, delink_callback: Callable =None, menubar: bool =False) -> Union[int, str]:
	"""
	Adds a node editor.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**delink_callback (Callable): Callback ran when a link is detached.
		**menubar (bool): Shows or hides the menubar.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_node_editor(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, delink_callback=delink_callback, menubar=menubar)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def plot(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, no_title: bool =False, no_menus: bool =False, no_box_select: bool =False, no_mouse_pos: bool =False, no_highlight: bool =False, no_child: bool =False, query: bool =False, crosshairs: bool =False, anti_aliased: bool =False, equal_aspects: bool =False, pan_button: int =internal_dpg.mvMouseButton_Left, pan_mod: int =-1, fit_button: int =internal_dpg.mvMouseButton_Left, context_menu_button: int =internal_dpg.mvMouseButton_Right, box_select_button: int =internal_dpg.mvMouseButton_Right, box_select_mod: int =-1, box_select_cancel_button: int =internal_dpg.mvMouseButton_Left, query_button: int =internal_dpg.mvMouseButton_Middle, query_mod: int =-1, query_toggle_mod: int =internal_dpg.mvKey_Control, horizontal_mod: int =internal_dpg.mvKey_Alt, vertical_mod: int =internal_dpg.mvKey_Shift) -> Union[int, str]:
	"""
	Adds a plot which is used to hold series, and can be drawn to with draw commands.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**no_title (bool): 
		**no_menus (bool): 
		**no_box_select (bool): 
		**no_mouse_pos (bool): 
		**no_highlight (bool): 
		**no_child (bool): 
		**query (bool): 
		**crosshairs (bool): 
		**anti_aliased (bool): 
		**equal_aspects (bool): 
		**pan_button (int): enables panning when held
		**pan_mod (int): optional modifier that must be held for panning
		**fit_button (int): fits visible data when double clicked
		**context_menu_button (int): opens plot context menu (if enabled) when clicked
		**box_select_button (int): begins box selection when pressed and confirms selection when released
		**box_select_mod (int): begins box selection when pressed and confirms selection when released
		**box_select_cancel_button (int): cancels active box selection when pressed
		**query_button (int): begins query selection when pressed and end query selection when released
		**query_mod (int): optional modifier that must be held for query selection
		**query_toggle_mod (int): when held, active box selections turn into queries
		**horizontal_mod (int): expands active box selection/query horizontally to plot edge when held
		**vertical_mod (int): expands active box selection/query vertically to plot edge when held
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_plot(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, no_title=no_title, no_menus=no_menus, no_box_select=no_box_select, no_mouse_pos=no_mouse_pos, no_highlight=no_highlight, no_child=no_child, query=query, crosshairs=crosshairs, anti_aliased=anti_aliased, equal_aspects=equal_aspects, pan_button=pan_button, pan_mod=pan_mod, fit_button=fit_button, context_menu_button=context_menu_button, box_select_button=box_select_button, box_select_mod=box_select_mod, box_select_cancel_button=box_select_cancel_button, query_button=query_button, query_mod=query_mod, query_toggle_mod=query_toggle_mod, horizontal_mod=horizontal_mod, vertical_mod=vertical_mod)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def staging_container(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_staging_container(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def subplots(rows : int, columns : int, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, row_ratios: Union[List[float], Tuple[float]] =[], column_ratios: Union[List[float], Tuple[float]] =[], no_title: bool =False, no_menus: bool =False, no_resize: bool =False, no_align: bool =False, link_rows: bool =False, link_columns: bool =False, link_all_x: bool =False, link_all_y: bool =False, column_major: bool =False) -> Union[int, str]:
	"""
	Adds a plot which is used to hold series, and can be drawn to with draw commands.
	Args:
		rows (int): 
		columns (int): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**row_ratios (Union[List[float], Tuple[float]]): 
		**column_ratios (Union[List[float], Tuple[float]]): 
		**no_title (bool): 
		**no_menus (bool): the user will not be able to open context menus with right-click
		**no_resize (bool): resize splitters between subplot cells will be not be provided
		**no_align (bool): subplot edges will not be aligned vertically or horizontally
		**link_rows (bool): link the y-axis limits of all plots in each row (does not apply auxiliary y-axes)
		**link_columns (bool): link the x-axis limits of all plots in each column
		**link_all_x (bool): link the x-axis limits in every plot in the subplot
		**link_all_y (bool): link the y-axis limits in every plot in the subplot (does not apply to auxiliary y-axes)
		**column_major (bool): subplots are added in column major order instead of the default row major order
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_subplots(rows, columns, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, callback=callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, row_ratios=row_ratios, column_ratios=column_ratios, no_title=no_title, no_menus=no_menus, no_resize=no_resize, no_align=no_align, link_rows=link_rows, link_columns=link_columns, link_all_x=link_all_x, link_all_y=link_all_y, column_major=column_major)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def tab(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, closable: bool =False, no_tooltip: bool =False, order_mode: bool =0) -> Union[int, str]:
	"""
	Adds a tab to a tab bar. Must be closed with thes end command.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**closable (bool): Creates a button on the tab that can hide the tab.
		**no_tooltip (bool): Disable tooltip for the given tab.
		**order_mode (bool): set using a constant: mvTabOrder_Reorderable: allows reordering, mvTabOrder_Fixed: fixed ordering, mvTabOrder_Leading: adds tab to front, mvTabOrder_Trailing: adds tab to back
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_tab(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, closable=closable, no_tooltip=no_tooltip, order_mode=order_mode)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def tab_bar(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, reorderable: bool =False) -> Union[int, str]:
	"""
	Adds a tab bar.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**reorderable (bool): Allows for the user to change the order of the tabs.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_tab_bar(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, reorderable=reorderable)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def table(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, header_row: bool =True, inner_width: int =0, policy: int =0, freeze_rows: int =0, freeze_columns: int =0, sort_multi: bool =False, sort_tristate: bool =False, resizable: bool =False, reorderable: bool =False, hideable: bool =False, sortable: bool =False, context_menu_in_body: bool =False, row_background: bool =False, borders_innerH: bool =False, borders_outerH: bool =False, borders_innerV: bool =False, borders_outerV: bool =False, no_host_extendX: bool =False, no_host_extendY: bool =False, no_keep_columns_visible: bool =False, precise_widths: bool =False, no_clip: bool =False, pad_outerX: bool =False, no_pad_outerX: bool =False, no_pad_innerX: bool =False, scrollX: bool =False, scrollY: bool =False, no_saved_settings: bool =False) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**header_row (bool): show headers at the top of the columns
		**inner_width (int): 
		**policy (int): 
		**freeze_rows (int): 
		**freeze_columns (int): 
		**sort_multi (bool): Hold shift when clicking headers to sort on multiple column.
		**sort_tristate (bool): Allow no sorting, disable default sorting.
		**resizable (bool): Enable resizing columns
		**reorderable (bool): Enable reordering columns in header row (need calling TableSetupColumn() + TableHeadersRow() to display headers)
		**hideable (bool): Enable hiding/disabling columns in context menu.
		**sortable (bool): Enable sorting. Call TableGetSortSpecs() to obtain sort specs. Also see ImGuiTableFlags_SortMulti and ImGuiTableFlags_SortTristate.
		**context_menu_in_body (bool): Right-click on columns body/contents will display table context menu. By default it is available in TableHeadersRow().
		**row_background (bool): Set each RowBg color with ImGuiCol_TableRowBg or ImGuiCol_TableRowBgAlt (equivalent of calling TableSetBgColor with ImGuiTableBgFlags_RowBg0 on each row manually)
		**borders_innerH (bool): Draw horizontal borders between rows.
		**borders_outerH (bool): Draw horizontal borders at the top and bottom.
		**borders_innerV (bool): Draw vertical borders between columns.
		**borders_outerV (bool): Draw vertical borders on the left and right sides.
		**no_host_extendX (bool): Make outer width auto-fit to columns, overriding outer_size.x value. Only available when ScrollX/ScrollY are disabled and Stretch columns are not used.
		**no_host_extendY (bool): Make outer height stop exactly at outer_size.y (prevent auto-extending table past the limit). Only available when ScrollX/ScrollY are disabled. Data below the limit will be clipped and not visible.
		**no_keep_columns_visible (bool): Disable keeping column always minimally visible when ScrollX is off and table gets too small. Not recommended if columns are resizable.
		**precise_widths (bool): Disable distributing remainder width to stretched columns (width allocation on a 100-wide table with 3 columns: Without this flag: 33,33,34. With this flag: 33,33,33). With larger number of columns, resizing will appear to be less smooth.
		**no_clip (bool): Disable clipping rectangle for every individual columns.
		**pad_outerX (bool): Default if BordersOuterV is on. Enable outer-most padding. Generally desirable if you have headers.
		**no_pad_outerX (bool): Default if BordersOuterV is off. Disable outer-most padding.
		**no_pad_innerX (bool): Disable inner padding between columns (double inner padding if BordersOuterV is on, single inner padding if BordersOuterV is off).
		**scrollX (bool): Enable horizontal scrolling. Require 'outer_size' parameter of BeginTable() to specify the container size. Changes default sizing policy. Because this create a child window, ScrollY is currently generally recommended when using ScrollX.
		**scrollY (bool): Enable vertical scrolling.
		**no_saved_settings (bool): Never load/save settings in .ini file.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_table(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, callback=callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, header_row=header_row, inner_width=inner_width, policy=policy, freeze_rows=freeze_rows, freeze_columns=freeze_columns, sort_multi=sort_multi, sort_tristate=sort_tristate, resizable=resizable, reorderable=reorderable, hideable=hideable, sortable=sortable, context_menu_in_body=context_menu_in_body, row_background=row_background, borders_innerH=borders_innerH, borders_outerH=borders_outerH, borders_innerV=borders_innerV, borders_outerV=borders_outerV, no_host_extendX=no_host_extendX, no_host_extendY=no_host_extendY, no_keep_columns_visible=no_keep_columns_visible, precise_widths=precise_widths, no_clip=no_clip, pad_outerX=pad_outerX, no_pad_outerX=no_pad_outerX, no_pad_innerX=no_pad_innerX, scrollX=scrollX, scrollY=scrollY, no_saved_settings=no_saved_settings)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def table_row(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, height: int =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, filter_key: str ='') -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**height (int): Height of the item.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**filter_key (str): Used by filter widget.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_table_row(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, height=height, parent=parent, before=before, show=show, filter_key=filter_key)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def texture_registry(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, show: bool =False) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**show (bool): Attempt to render widget.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_texture_registry(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, show=show)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def theme(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, default_theme: bool =False) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**default_theme (bool): 
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_theme(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, default_theme=default_theme)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def tooltip(parent : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Adds an advanced tool tip for an item. This command must come immediately after the item the tip is for.
	Args:
		parent (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**show (bool): Attempt to render widget.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_tooltip(parent, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, show=show)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def tree_node(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, default_open: bool =False, open_on_double_click: bool =False, open_on_arrow: bool =False, leaf: bool =False, bullet: bool =False, selectable: bool =False) -> Union[int, str]:
	"""
	Adds a tree node to add items to. Must be closed with the end command.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_open (bool): Sets the tree node open by default.
		**open_on_double_click (bool): Need double-click to open node.
		**open_on_arrow (bool): Only open when clicking on the arrow part.
		**leaf (bool): No collapsing, no arrow (use as a convenience for leaf nodes).
		**bullet (bool): Display a bullet instead of arrow.
		**selectable (bool): Makes the tree selectable.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_tree_node(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, default_open=default_open, open_on_double_click=open_on_double_click, open_on_arrow=open_on_arrow, leaf=leaf, bullet=bullet, selectable=selectable)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def value_registry(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_value_registry(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def viewport_drawlist(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, show: bool =True, filter_key: str ='', delay_search: bool =False, front: bool =True) -> Union[int, str]:
	"""
	A container that is used to present draw items or layers directly to the viewport. By default this will draw to the back of teh viewport. Layers and draw items should be added to this widget as children.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**show (bool): Attempt to render widget.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**front (bool): Draws to the front of the view port instead of the back.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_viewport_drawlist(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, show=show, filter_key=filter_key, delay_search=delay_search, front=front)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def viewport_menu_bar(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, show: bool =True, delay_search: bool =False) -> Union[int, str]:
	"""
	Adds a menu bar to the viewport.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**show (bool): Attempt to render widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_viewport_menu_bar(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, show=show, delay_search=delay_search)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()
@contextmanager
def window(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, show: bool =True, pos: Union[List[int], Tuple[int]] =[], delay_search: bool =False, min_size: Union[List[int], Tuple[int]] =[100, 100], max_size: Union[List[int], Tuple[int]] =[30000, 30000], menubar: bool =False, collapsed: bool =False, autosize: bool =False, no_resize: bool =False, no_title_bar: bool =False, no_move: bool =False, no_scrollbar: bool =False, no_collapse: bool =False, horizontal_scrollbar: bool =False, no_focus_on_appearing: bool =False, no_bring_to_front_on_focus: bool =False, no_close: bool =False, no_background: bool =False, modal: bool =False, popup: bool =False, no_saved_settings: bool =False, on_close: Callable =None) -> Union[int, str]:
	"""
	Creates a new window for following items to be added to.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**min_size (Union[List[int], Tuple[int]]): Minimum window size.
		**max_size (Union[List[int], Tuple[int]]): Maximum window size.
		**menubar (bool): Shows or hides the menubar.
		**collapsed (bool): Collapse the window.
		**autosize (bool): Autosized the window to fit it's items.
		**no_resize (bool): Allows for the window size to be changed or fixed.
		**no_title_bar (bool): Title name for the title bar of the window.
		**no_move (bool): Allows for the window's position to be changed or fixed.
		**no_scrollbar (bool):  Disable scrollbars. (window can still scroll with mouse or programmatically)
		**no_collapse (bool): Disable user collapsing window by double-clicking on it.
		**horizontal_scrollbar (bool): Allow horizontal scrollbar to appear. (off by default)
		**no_focus_on_appearing (bool): Disable taking focus when transitioning from hidden to visible state.
		**no_bring_to_front_on_focus (bool): Disable bringing window to front when taking focus. (e.g. clicking on it or programmatically giving it focus)
		**no_close (bool): Disable user closing the window by removing the close button.
		**no_background (bool): Sets Background and border alpha to transparent.
		**modal (bool): Fills area behind window according to the theme and disables user ability to interact with anything except the window.
		**popup (bool): Fills area behind window according to the theme, removes title bar, collapse and close. Window can be closed by selecting area in the background behind the window.
		**no_saved_settings (bool): Never load/save settings in .ini file.
		**on_close (Callable): Callback ran when window is closed.
	Yields:
		Union[int, str]
	"""
	try:
		widget = internal_dpg.add_window(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, show=show, pos=pos, delay_search=delay_search, min_size=min_size, max_size=max_size, menubar=menubar, collapsed=collapsed, autosize=autosize, no_resize=no_resize, no_title_bar=no_title_bar, no_move=no_move, no_scrollbar=no_scrollbar, no_collapse=no_collapse, horizontal_scrollbar=horizontal_scrollbar, no_focus_on_appearing=no_focus_on_appearing, no_bring_to_front_on_focus=no_bring_to_front_on_focus, no_close=no_close, no_background=no_background, modal=modal, popup=popup, no_saved_settings=no_saved_settings, on_close=on_close)
		internal_dpg.push_container_stack(widget)
		yield widget
	finally:
		internal_dpg.pop_container_stack()

##########################################################
# Core Wrappings
##########################################################

def add_2d_histogram_series(x : Union[List[float], Tuple[float]], y : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, xbins: int =-1, ybins: int =-1, xmin_range: float =0.0, xmax_range: float =1.0, ymin_range: float =0.0, ymax_range: float =1.0, density: bool =False, outliers: bool =True) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		x (Any): 
		y (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**xbins (int): 
		**ybins (int): 
		**xmin_range (float): 
		**xmax_range (float): 
		**ymin_range (float): 
		**ymax_range (float): 
		**density (bool): 
		**outliers (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_2d_histogram_series(x, y, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show, xbins=xbins, ybins=ybins, xmin_range=xmin_range, xmax_range=xmax_range, ymin_range=ymin_range, ymax_range=ymax_range, density=density, outliers=outliers)

def add_3d_slider(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: Union[List[float], Tuple[float]] =(0.0, 0.0, 0.0, 0.0), max_x: float =100.0, max_y: float =100.0, max_z: float =100.0, min_x: float =0.0, min_y: float =0.0, min_z: float =0.0, scale: float =1.0) -> Union[int, str]:
	"""
	Adds a 3D box slider that allows a 3d point to be show in 2d represented cube space.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (Union[List[float], Tuple[float]]): 
		**max_x (float): Applies upper limit to slider.
		**max_y (float): Applies upper limit to slider.
		**max_z (float): Applies upper limit to slider.
		**min_x (float): Applies lower limit to slider.
		**min_y (float): Applies lower limit to slider.
		**min_z (float): Applies lower limit to slider.
		**scale (float): Size of the widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_3d_slider(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, max_x=max_x, max_y=max_y, max_z=max_z, min_x=min_x, min_y=min_y, min_z=min_z, scale=scale)

def add_activated_handler(parent : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified item is activated.
	Args:
		parent (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_activated_handler(parent, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show)

def add_active_handler(parent : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified item is active.
	Args:
		parent (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_active_handler(parent, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show)

def add_alias(alias : str, item : Union[int, str]) -> None:
	"""
	Undocumented
	Args:
		alias (str): 
		item (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.add_alias(alias, item)

def add_area_series(x : Union[List[float], Tuple[float]], y : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, fill: Union[List[int], Tuple[int]] =(0, 0, 0, -255), contribute_to_bounds: bool =True) -> Union[int, str]:
	"""
	Adds an area series to a plot.
	Args:
		x (Any): 
		y (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**fill (Union[List[int], Tuple[int]]): 
		**contribute_to_bounds (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_area_series(x, y, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show, fill=fill, contribute_to_bounds=contribute_to_bounds)

def add_bar_series(x : Union[List[float], Tuple[float]], y : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, weight: float =1.0, horizontal: bool =False) -> Union[int, str]:
	"""
	Adds a bar series to a plot.
	Args:
		x (Any): 
		y (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**weight (float): 
		**horizontal (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_bar_series(x, y, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show, weight=weight, horizontal=horizontal)

def add_bool_value(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, source: Union[int, str] =0, default_value: bool =False, parent: Union[int, str] =internal_dpg.mvReservedUUID_3) -> Union[int, str]:
	"""
	Undocumented
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**default_value (bool): 
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_bool_value(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, source=source, default_value=default_value, parent=parent)

def add_button(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, small: bool =False, arrow: bool =False, direction: int =0) -> Union[int, str]:
	"""
	Adds a button.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**small (bool): Small button, useful for embedding in text.
		**arrow (bool): Arrow button, requires the direction keyword.
		**direction (int): A cardinal direction for arrow.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_button(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, small=small, arrow=arrow, direction=direction)

def add_candle_series(dates : Union[List[float], Tuple[float]], opens : Union[List[float], Tuple[float]], closes : Union[List[float], Tuple[float]], lows : Union[List[float], Tuple[float]], highs : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, bull_color: Union[List[int], Tuple[int]] =(0, 255, 113, 255), bear_color: Union[List[int], Tuple[int]] =(218, 13, 79, 255), weight: int =0.25, tooltip: bool =True) -> Union[int, str]:
	"""
	Adds a candle series to a plot.
	Args:
		dates (Any): 
		opens (Any): 
		closes (Any): 
		lows (Any): 
		highs (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**bull_color (Union[List[int], Tuple[int]]): 
		**bear_color (Union[List[int], Tuple[int]]): 
		**weight (int): 
		**tooltip (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_candle_series(dates, opens, closes, lows, highs, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show, bull_color=bull_color, bear_color=bear_color, weight=weight, tooltip=tooltip)

def add_char_remap(source : int, target : int, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		source (int): 
		target (int): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_char_remap(source, target, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent)

def add_checkbox(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: bool =False) -> Union[int, str]:
	"""
	Adds a checkbox.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_checkbox(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value)

def add_child(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, border: bool =True, autosize_x: bool =False, autosize_y: bool =False, no_scrollbar: bool =False, horizontal_scrollbar: bool =False, menubar: bool =False) -> Union[int, str]:
	"""
	Adds an embedded child window. Will show scrollbars when items do not fit. Must be followed by a call to end.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**border (bool): Shows/Hides the border around the sides.
		**autosize_x (bool): Autosize the window to fit it's items in the x.
		**autosize_y (bool): Autosize the window to fit it's items in the y.
		**no_scrollbar (bool):  Disable scrollbars (window can still scroll with mouse or programmatically).
		**horizontal_scrollbar (bool): Allow horizontal scrollbar to appear (off by default).
		**menubar (bool): Shows/Hides the menubar at the top.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_child(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, border=border, autosize_x=autosize_x, autosize_y=autosize_y, no_scrollbar=no_scrollbar, horizontal_scrollbar=horizontal_scrollbar, menubar=menubar)

def add_clicked_handler(parent : Union[int, str], button : int =-1, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified item is clicked.
	Args:
		parent (Union[int, str]): 
		*button (int): Submits callback for all mouse buttons
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_clicked_handler(parent, button, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show)

def add_clipper(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, delay_search: bool =False) -> Union[int, str]:
	"""
	Helper to manually clip large list of items. Increases performance by not searching or drawing widgets outside of the clipped region.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_clipper(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, show=show, delay_search=delay_search)

def add_collapsing_header(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, closable: bool =False, default_open: bool =False, open_on_double_click: bool =False, open_on_arrow: bool =False, leaf: bool =False, bullet: bool =False) -> Union[int, str]:
	"""
	Adds a collapsing header to add items to. Must be closed with the end command.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**closable (bool): Adds the ability to hide this widget by pressing the (x) in the top right of widget.
		**default_open (bool): Sets the collapseable header open by default.
		**open_on_double_click (bool): Need double-click to open node.
		**open_on_arrow (bool): Only open when clicking on the arrow part.
		**leaf (bool): No collapsing, no arrow (use as a convenience for leaf nodes).
		**bullet (bool): Display a bullet instead of arrow.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_collapsing_header(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, closable=closable, default_open=default_open, open_on_double_click=open_on_double_click, open_on_arrow=open_on_arrow, leaf=leaf, bullet=bullet)

def add_color_button(default_value : Union[List[int], Tuple[int]] =(0, 0, 0, 255), *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, no_alpha: bool =False, no_border: bool =False, no_drag_drop: bool =False) -> Union[int, str]:
	"""
	Adds a color button.
	Args:
		*default_value (Union[List[int], Tuple[int]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**no_alpha (bool): Ignore Alpha component.
		**no_border (bool): Disable border around the image.
		**no_drag_drop (bool): Disable display of inline text label.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_color_button(default_value, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, no_alpha=no_alpha, no_border=no_border, no_drag_drop=no_drag_drop)

def add_color_edit(default_value : Union[List[int], Tuple[int]] =(0, 0, 0, 255), *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, no_alpha: bool =False, no_picker: bool =False, no_options: bool =False, no_small_preview: bool =False, no_inputs: bool =False, no_tooltip: bool =False, no_label: bool =False, no_drag_drop: bool =False, alpha_bar: bool =False, alpha_preview: int =0, display_mode: int =1048576, display_type: int =8388608, input_mode: int =134217728) -> Union[int, str]:
	"""
	Adds an RGBA color editor. Click the small color preview will provide a color picker. Click and draging the small color preview will copy the color to be applied on any other color widget.
	Args:
		*default_value (Union[List[int], Tuple[int]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**no_alpha (bool): Disable Alpha component.
		**no_picker (bool): Disable picker popup when color square is clicked.
		**no_options (bool): Disable toggling options menu when right-clicking on inputs/small preview.
		**no_small_preview (bool): Disable colored square preview next to the inputs. (e.g. to show only the inputs). This only displays if the side preview is not shown.
		**no_inputs (bool): Disable inputs sliders/text widgets. (e.g. to show only the small preview colored square)
		**no_tooltip (bool): Disable tooltip when hovering the preview.
		**no_label (bool): Disable display of inline text label.
		**no_drag_drop (bool): Disable ability to drag and drop small preview (color square) to apply colors.
		**alpha_bar (bool): Show vertical alpha bar/gradient in picker.
		**alpha_preview (int): mvColorEdit_AlphaPreviewNone, mvColorEdit_AlphaPreview, or mvColorEdit_AlphaPreviewHalf
		**display_mode (int): mvColorEdit_rgb, mvColorEdit_hsv, or mvColorEdit_hex
		**display_type (int): mvColorEdit_uint8 or mvColorEdit_float
		**input_mode (int): mvColorEdit_input_rgb or mvColorEdit_input_hsv
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_color_edit(default_value, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, no_alpha=no_alpha, no_picker=no_picker, no_options=no_options, no_small_preview=no_small_preview, no_inputs=no_inputs, no_tooltip=no_tooltip, no_label=no_label, no_drag_drop=no_drag_drop, alpha_bar=alpha_bar, alpha_preview=alpha_preview, display_mode=display_mode, display_type=display_type, input_mode=input_mode)

def add_color_picker(default_value : Union[List[int], Tuple[int]] =(0, 0, 0, 255), *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, no_alpha: bool =False, no_side_preview: bool =False, no_small_preview: bool =False, no_inputs: bool =False, no_tooltip: bool =False, no_label: bool =False, alpha_bar: bool =False, display_rgb: bool =False, display_hsv: bool =False, display_hex: bool =False, picker_mode: int =33554432, alpha_preview: int =0, display_type: int =8388608, input_mode: int =134217728) -> Union[int, str]:
	"""
	Adds an RGB color picker. Right click the color picker for options. Click and drag the color preview to copy the color and drop on any other color widget to apply. Right Click allows the style of the color picker to be changed.
	Args:
		*default_value (Union[List[int], Tuple[int]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**no_alpha (bool): Ignore Alpha component.
		**no_side_preview (bool): Disable bigger color preview on right side of the picker, use small colored square preview instead , unless small preview is also hidden.
		**no_small_preview (bool): Disable colored square preview next to the inputs. (e.g. to show only the inputs). This only displays if the side preview is not shown.
		**no_inputs (bool): Disable inputs sliders/text widgets. (e.g. to show only the small preview colored square)
		**no_tooltip (bool): Disable tooltip when hovering the preview.
		**no_label (bool): Disable display of inline text label.
		**alpha_bar (bool): Show vertical alpha bar/gradient in picker.
		**display_rgb (bool): Override _display_ type among RGB/HSV/Hex.
		**display_hsv (bool): Override _display_ type among RGB/HSV/Hex.
		**display_hex (bool): Override _display_ type among RGB/HSV/Hex.
		**picker_mode (int): mvColorPicker_bar or mvColorPicker_wheel
		**alpha_preview (int): mvColorEdit_AlphaPreviewNone, mvColorEdit_AlphaPreview, or mvColorEdit_AlphaPreviewHalf
		**display_type (int): mvColorEdit_uint8 or mvColorEdit_float
		**input_mode (int): mvColorEdit_input_rgb or mvColorEdit_input_hsv
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_color_picker(default_value, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, no_alpha=no_alpha, no_side_preview=no_side_preview, no_small_preview=no_small_preview, no_inputs=no_inputs, no_tooltip=no_tooltip, no_label=no_label, alpha_bar=alpha_bar, display_rgb=display_rgb, display_hsv=display_hsv, display_hex=display_hex, picker_mode=picker_mode, alpha_preview=alpha_preview, display_type=display_type, input_mode=input_mode)

def add_color_value(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, source: Union[int, str] =0, default_value: Union[List[float], Tuple[float]] =(0.0, 0.0, 0.0, 0.0), parent: Union[int, str] =internal_dpg.mvReservedUUID_3) -> Union[int, str]:
	"""
	Undocumented
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**default_value (Union[List[float], Tuple[float]]): 
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_color_value(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, source=source, default_value=default_value, parent=parent)

def add_colormap(colors : List[List[int]], qualitative : bool, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, show: bool =True, parent: Union[int, str] =internal_dpg.mvReservedUUID_4) -> Union[int, str]:
	"""
	Adds a legend that pairs values with colors. This is typically used with a heat series. 
	Args:
		colors (Any): 
		qualitative (bool): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**show (bool): Attempt to render widget.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_colormap(colors, qualitative, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, show=show, parent=parent)

def add_colormap_button(default_value : Union[List[int], Tuple[int]] =(0, 0, 0, 255), *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, no_alpha: bool =False, no_border: bool =False, no_drag_drop: bool =False) -> Union[int, str]:
	"""
	Adds a color button.
	Args:
		*default_value (Union[List[int], Tuple[int]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**no_alpha (bool): Ignore Alpha component.
		**no_border (bool): Disable border around the image.
		**no_drag_drop (bool): Disable display of inline text label.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_colormap_button(default_value, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, no_alpha=no_alpha, no_border=no_border, no_drag_drop=no_drag_drop)

def add_colormap_registry(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, show: bool =False) -> Union[int, str]:
	"""
	Adds a colormap registry.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_colormap_registry(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, show=show)

def add_colormap_scale(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, pos: Union[List[int], Tuple[int]] =[], colormap: Union[int, str] =0, min_scale: float =0.0, max_scale: float =1.0) -> Union[int, str]:
	"""
	Adds a legend that pairs values with colors. This is typically used with a heat series. 
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**colormap (Union[int, str]): mvPlotColormap_* constants or mvColorMap uuid
		**min_scale (float): Sets the min number of the color scale. Typically is the same as the min scale from the heat series.
		**max_scale (float): Sets the max number of the color scale. Typically is the same as the max scale from the heat series.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_colormap_scale(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, show=show, pos=pos, colormap=colormap, min_scale=min_scale, max_scale=max_scale)

def add_colormap_slider(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: float =0.0) -> Union[int, str]:
	"""
	Adds a color button.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (float): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_colormap_slider(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value)

def add_combo(items : Union[List[str], Tuple[str]] =(), *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: str ='', popup_align_left: bool =False, no_arrow_button: bool =False, no_preview: bool =False, height_mode: int =1) -> Union[int, str]:
	"""
	Adds a combo dropdown that allows a user to select a single option from a drop down window.
	Args:
		*items (Union[List[str], Tuple[str]]): A tuple of items to be shown in the drop down window. Can consist of any combination of types.
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (str): 
		**popup_align_left (bool): Align the popup toward the left.
		**no_arrow_button (bool): Display the preview box without the square arrow button.
		**no_preview (bool): Display only the square arrow button.
		**height_mode (int): mvComboHeight_Small, _Regular, _Large, _Largest
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_combo(items, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, popup_align_left=popup_align_left, no_arrow_button=no_arrow_button, no_preview=no_preview, height_mode=height_mode)

def add_date_picker(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: dict ={'month_day': 14, 'year':20, 'month':5}, level: int =0) -> Union[int, str]:
	"""
	Creates a date picker.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (dict): 
		**level (int): Use avaliable constants. mvDatePickerLevel_Day, mvDatePickerLevel_Month, mvDatePickerLevel_Year
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_date_picker(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, level=level)

def add_deactivated_after_edit_handler(parent : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified item is deactivated after edit.
	Args:
		parent (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_deactivated_after_edit_handler(parent, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show)

def add_deactivated_handler(parent : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified item is deactivated.
	Args:
		parent (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_deactivated_handler(parent, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show)

def add_double4_value(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, source: Union[int, str] =0, default_value: Any =(0.0, 0.0, 0.0, 0.0), parent: Union[int, str] =internal_dpg.mvReservedUUID_3) -> Union[int, str]:
	"""
	Undocumented
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**default_value (Any): 
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_double4_value(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, source=source, default_value=default_value, parent=parent)

def add_double_value(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, source: Union[int, str] =0, default_value: float =0.0, parent: Union[int, str] =internal_dpg.mvReservedUUID_3) -> Union[int, str]:
	"""
	Undocumented
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**default_value (float): 
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_double_value(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, source=source, default_value=default_value, parent=parent)

def add_drag_float(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: float =0.0, format: str ='%0.3f', speed: float =1.0, min_value: float =0.0, max_value: float =100.0, no_input: bool =False, clamped: bool =False) -> Union[int, str]:
	"""
	Adds drag for a single float value. Directly entry can be done with double click or CTRL+Click. Min and Max alone are a soft limit for the drag. Use clamped keyword to also apply limits to the direct entry modes.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (float): 
		**format (str): 
		**speed (float): 
		**min_value (float): Applies a limit only to draging entry only.
		**max_value (float): Applies a limit only to draging entry only.
		**no_input (bool): Disable direct entry methods or Enter key allowing to input text directly into the widget.
		**clamped (bool): Applies the min and max limits to direct entry methods also such as double click and CTRL+Click.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_drag_float(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, format=format, speed=speed, min_value=min_value, max_value=max_value, no_input=no_input, clamped=clamped)

def add_drag_floatx(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: Union[List[float], Tuple[float]] =(0.0, 0.0, 0.0, 0.0), size: int =4, format: str ='%0.3f', speed: float =1.0, min_value: float =0.0, max_value: float =100.0, no_input: bool =False, clamped: bool =False) -> Union[int, str]:
	"""
	Adds drag input for a set of int values up to 4. Directly entry can be done with double click or CTRL+Click. Min and Max alone are a soft limit for the drag. Use clamped keyword to also apply limits to the direct entry modes.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (Union[List[float], Tuple[float]]): 
		**size (int): Number of components
		**format (str): 
		**speed (float): 
		**min_value (float): Applies a limit only to draging entry only.
		**max_value (float): Applies a limit only to draging entry only.
		**no_input (bool): Disable direct entry methods or Enter key allowing to input text directly into the widget.
		**clamped (bool): Applies the min and max limits to direct entry methods also such as double click and CTRL+Click.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_drag_floatx(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, size=size, format=format, speed=speed, min_value=min_value, max_value=max_value, no_input=no_input, clamped=clamped)

def add_drag_int(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: int =0, format: str ='%d', speed: float =1.0, min_value: int =0, max_value: int =100, no_input: bool =False, clamped: bool =False) -> Union[int, str]:
	"""
	Adds drag for a single int value. Directly entry can be done with double click or CTRL+Click. Min and Max alone are a soft limit for the drag. Use clamped keyword to also apply limits to the direct entry modes.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (int): 
		**format (str): 
		**speed (float): 
		**min_value (int): Applies a limit only to draging entry only.
		**max_value (int): Applies a limit only to draging entry only.
		**no_input (bool): Disable direct entry methods or Enter key allowing to input text directly into the widget.
		**clamped (bool): Applies the min and max limits to direct entry methods also such as double click and CTRL+Click.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_drag_int(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, format=format, speed=speed, min_value=min_value, max_value=max_value, no_input=no_input, clamped=clamped)

def add_drag_intx(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: Union[List[int], Tuple[int]] =(0, 0, 0, 0), size: int =4, format: str ='%d', speed: float =1.0, min_value: int =0, max_value: int =100, no_input: bool =False, clamped: bool =False) -> Union[int, str]:
	"""
	Adds drag input for a set of int values up to 4. Directly entry can be done with double click or CTRL+Click. Min and Max alone are a soft limit for the drag. Use clamped keyword to also apply limits to the direct entry modes.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (Union[List[int], Tuple[int]]): 
		**size (int): Number of components.
		**format (str): 
		**speed (float): 
		**min_value (int): Applies a limit only to draging entry only.
		**max_value (int): Applies a limit only to draging entry only.
		**no_input (bool): Disable direct entry methods or Enter key allowing to input text directly into the widget.
		**clamped (bool): Applies the min and max limits to direct entry methods also such as double click and CTRL+Click.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_drag_intx(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, size=size, format=format, speed=speed, min_value=min_value, max_value=max_value, no_input=no_input, clamped=clamped)

def add_drag_line(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, callback: Callable =None, show: bool =True, default_value: Any =0.0, color: Union[List[int], Tuple[int]] =(0, 0, 0, -255), thickness: float =1.0, show_label: bool =True, vertical: bool =True) -> Union[int, str]:
	"""
	Adds a drag line to a plot.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**default_value (Any): 
		**color (Union[List[int], Tuple[int]]): 
		**thickness (float): 
		**show_label (bool): 
		**vertical (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_drag_line(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, callback=callback, show=show, default_value=default_value, color=color, thickness=thickness, show_label=show_label, vertical=vertical)

def add_drag_payload(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, show: bool =True, drag_data: Any =None, payload_type: str ='$$DPG_PAYLOAD') -> Union[int, str]:
	"""
	User data payload for drag and drop operations.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**show (bool): Attempt to render widget.
		**drag_data (Any): Drag data
		**payload_type (str): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_drag_payload(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, show=show, drag_data=drag_data, payload_type=payload_type)

def add_drag_point(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, callback: Callable =None, show: bool =True, default_value: Any =(0.0, 0.0), color: Union[List[int], Tuple[int]] =(0, 0, 0, -255), thickness: float =1.0, show_label: bool =True) -> Union[int, str]:
	"""
	Adds a drag point to a plot.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**default_value (Any): 
		**color (Union[List[int], Tuple[int]]): 
		**thickness (float): 
		**show_label (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_drag_point(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, callback=callback, show=show, default_value=default_value, color=color, thickness=thickness, show_label=show_label)

def add_draw_layer(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Creates a layer that can be drawn to. Useful for grouping drawing items.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_draw_layer(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show)

def add_drawlist(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5) -> Union[int, str]:
	"""
	A container widget that is used to present draw items or layers. Layers and draw items should be added to this widget as children.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_drawlist(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset)

def add_dummy(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, pos: Union[List[int], Tuple[int]] =[]) -> Union[int, str]:
	"""
	Adds a spacer or 'dummy' object.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_dummy(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, show=show, pos=pos)

def add_dynamic_texture(width : int, height : int, default_value : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =internal_dpg.mvReservedUUID_2) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		width (int): 
		height (int): 
		default_value (Union[List[float], Tuple[float]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_dynamic_texture(width, height, default_value, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent)

def add_edited_handler(parent : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified item is edited.
	Args:
		parent (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_edited_handler(parent, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show)

def add_error_series(x : Union[List[float], Tuple[float]], y : Union[List[float], Tuple[float]], negative : Union[List[float], Tuple[float]], positive : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, contribute_to_bounds: bool =True, horizontal: bool =False) -> Union[int, str]:
	"""
	Adds an error series to a plot.
	Args:
		x (Any): 
		y (Any): 
		negative (Any): 
		positive (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**contribute_to_bounds (bool): 
		**horizontal (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_error_series(x, y, negative, positive, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show, contribute_to_bounds=contribute_to_bounds, horizontal=horizontal)

def add_file_dialog(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, callback: Callable =None, show: bool =True, default_path: str ='', default_filename: str ='.', file_count: int =0, modal: bool =False, directory_selector: bool =False) -> Union[int, str]:
	"""
	Displays a file or directory selector depending on keywords. Displays a file dialog by default.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**default_path (str): Path that the file dialog will default to when opened.
		**default_filename (str): Default name that will show in the file name input.
		**file_count (int): Number of visible files in the dialog.
		**modal (bool): Forces user interaction with the file selector.
		**directory_selector (bool): Shows only directory/paths as options. Allows selection of directory/paths only.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_file_dialog(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, callback=callback, show=show, default_path=default_path, default_filename=default_filename, file_count=file_count, modal=modal, directory_selector=directory_selector)

def add_file_extension(extension : str, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, parent: Union[int, str] =0, before: Union[int, str] =0, custom_text: str ='', color: Union[List[float], Tuple[float]] =(-255, 0, 0, 255)) -> Union[int, str]:
	"""
	Creates a file extension filter option in the file dialog. Only works when the parent is a file dialog.
	Args:
		extension (str): Extension that will show as an when the parent is a file dialog.
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**custom_text (str): Replaces the displayed text in the drop down for this extension.
		**color (Union[List[float], Tuple[float]]): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_file_extension(extension, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, parent=parent, before=before, custom_text=custom_text, color=color)

def add_filter_set(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, delay_search: bool =False) -> Union[int, str]:
	"""
	Helper to parse and apply text filters (e.g. aaaaa[, bbbbb][, ccccc])
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_filter_set(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, show=show, delay_search=delay_search)

def add_float4_value(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, source: Union[int, str] =0, default_value: Union[List[float], Tuple[float]] =(0.0, 0.0, 0.0, 0.0), parent: Union[int, str] =internal_dpg.mvReservedUUID_3) -> Union[int, str]:
	"""
	Undocumented
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**default_value (Union[List[float], Tuple[float]]): 
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_float4_value(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, source=source, default_value=default_value, parent=parent)

def add_float_value(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, source: Union[int, str] =0, default_value: float =0.0, parent: Union[int, str] =internal_dpg.mvReservedUUID_3) -> Union[int, str]:
	"""
	Undocumented
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**default_value (float): 
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_float_value(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, source=source, default_value=default_value, parent=parent)

def add_float_vect_value(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, source: Union[int, str] =0, default_value: Union[List[float], Tuple[float]] =(), parent: Union[int, str] =internal_dpg.mvReservedUUID_3) -> Union[int, str]:
	"""
	Undocumented
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**default_value (Union[List[float], Tuple[float]]): 
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_float_vect_value(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, source=source, default_value=default_value, parent=parent)

def add_focus_handler(parent : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified item is focused.
	Args:
		parent (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_focus_handler(parent, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show)

def add_font(file : str, size : int, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, default_font: bool =False, parent: Union[int, str] =internal_dpg.mvReservedUUID_0) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		file (str): 
		size (int): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**default_font (bool): 
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_font(file, size, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, default_font=default_font, parent=parent)

def add_font_chars(chars : Union[List[int], Tuple[int]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		chars (Union[List[int], Tuple[int]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_font_chars(chars, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent)

def add_font_range(first_char : int, last_char : int, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		first_char (int): 
		last_char (int): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_font_range(first_char, last_char, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent)

def add_font_range_hint(hint : int, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		hint (int): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_font_range_hint(hint, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent)

def add_font_registry(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_font_registry(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, show=show)

def add_group(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, horizontal: bool =False, horizontal_spacing: float =-1) -> Union[int, str]:
	"""
	Creates a group that other widgets can belong to. The group allows item commands to be issued for all of its members. Must be closed with the end command.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**horizontal (bool): Forces child widgets to be added in a horizontal layout.
		**horizontal_spacing (float): Spacing for the horizontal layout.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_group(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, horizontal=horizontal, horizontal_spacing=horizontal_spacing)

def add_handler_registry(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Adds a handler registry.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_handler_registry(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, show=show)

def add_heat_series(x : Union[List[float], Tuple[float]], rows : int, cols : int, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, scale_min: float =0.0, scale_max: float =1.0, bounds_min: Any =(0.0, 0.0), bounds_max: Any =(1.0, 1.0), format: str ='%0.1f', contribute_to_bounds: bool =True) -> Union[int, str]:
	"""
	Adds a heat series to a plot. Typically a color scale widget is also added to show the legend.
	Args:
		x (Any): 
		rows (int): 
		cols (int): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**scale_min (float): Sets the color scale min. Typically paired with the color scale widget scale_min.
		**scale_max (float): Sets the color scale max. Typically paired with the color scale widget scale_max.
		**bounds_min (Any): 
		**bounds_max (Any): 
		**format (str): 
		**contribute_to_bounds (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_heat_series(x, rows, cols, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show, scale_min=scale_min, scale_max=scale_max, bounds_min=bounds_min, bounds_max=bounds_max, format=format, contribute_to_bounds=contribute_to_bounds)

def add_histogram_series(x : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, bins: int =-1, bar_scale: float =1.0, min_range: float =0.0, max_range: float =1.0, cumlative: bool =False, density: bool =False, outliers: bool =True, contribute_to_bounds: bool =True) -> Union[int, str]:
	"""
	Adds a histogram series to a plot.
	Args:
		x (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**bins (int): 
		**bar_scale (float): 
		**min_range (float): 
		**max_range (float): 
		**cumlative (bool): 
		**density (bool): 
		**outliers (bool): 
		**contribute_to_bounds (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_histogram_series(x, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show, bins=bins, bar_scale=bar_scale, min_range=min_range, max_range=max_range, cumlative=cumlative, density=density, outliers=outliers, contribute_to_bounds=contribute_to_bounds)

def add_hline_series(x : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, contribute_to_bounds: bool =True) -> Union[int, str]:
	"""
	Adds a infinite horizontal line series to a plot.
	Args:
		x (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**contribute_to_bounds (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_hline_series(x, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show, contribute_to_bounds=contribute_to_bounds)

def add_hover_handler(parent : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified item is hovered.
	Args:
		parent (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_hover_handler(parent, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show)

def add_image(texture_id : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, tint_color: Union[List[float], Tuple[float]] =(255, 255, 255, 255), border_color: Union[List[float], Tuple[float]] =(0, 0, 0, 0), uv_min: Union[List[float], Tuple[float]] =(0.0, 0.0), uv_max: Union[List[float], Tuple[float]] =(1.0, 1.0)) -> Union[int, str]:
	"""
	Adds an image from a specified texture. uv_min and uv_max represent the normalized texture coordinates of the original image that will be shown. Using range (0.0,0.0)->(1.0,1.0) for texture coordinates will generally display the entire texture.
	Args:
		texture_id (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**tint_color (Union[List[float], Tuple[float]]): Applies a color tint to the entire texture.
		**border_color (Union[List[float], Tuple[float]]): Displays a border of the specified color around the texture.
		**uv_min (Union[List[float], Tuple[float]]): Normalized texture coordinates min point.
		**uv_max (Union[List[float], Tuple[float]]): Normalized texture coordinates max point.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_image(texture_id, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, tint_color=tint_color, border_color=border_color, uv_min=uv_min, uv_max=uv_max)

def add_image_button(texture_id : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, frame_padding: int =-1, tint_color: Union[List[float], Tuple[float]] =(255, 255, 255, 255), background_color: Union[List[float], Tuple[float]] =(0, 0, 0, 0), uv_min: Union[List[float], Tuple[float]] =(0.0, 0.0), uv_max: Union[List[float], Tuple[float]] =(1.0, 1.0)) -> Union[int, str]:
	"""
	Adds an button with a texture. uv_min and uv_max represent the normalized texture coordinates of the original image that will be shown. Using range (0.0,0.0)->(1.0,1.0) texture coordinates will generally display the entire texture
	Args:
		texture_id (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**frame_padding (int): 
		**tint_color (Union[List[float], Tuple[float]]): Applies a color tint to the entire texture.
		**background_color (Union[List[float], Tuple[float]]): Displays a border of the specified color around the texture.
		**uv_min (Union[List[float], Tuple[float]]): Normalized texture coordinates min point.
		**uv_max (Union[List[float], Tuple[float]]): Normalized texture coordinates max point.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_image_button(texture_id, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, frame_padding=frame_padding, tint_color=tint_color, background_color=background_color, uv_min=uv_min, uv_max=uv_max)

def add_image_series(texture_id : Union[int, str], bounds_min : Union[List[float], Tuple[float]], bounds_max : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, uv_min: Union[List[float], Tuple[float]] =(0.0, 0.0), uv_max: Union[List[float], Tuple[float]] =(1.0, 1.0), tint_color: Union[List[int], Tuple[int]] =(255, 255, 255, 255)) -> Union[int, str]:
	"""
	Adds a image series to a plot.
	Args:
		texture_id (Union[int, str]): 
		bounds_min (Any): 
		bounds_max (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**uv_min (Union[List[float], Tuple[float]]): normalized texture coordinates
		**uv_max (Union[List[float], Tuple[float]]): normalized texture coordinates
		**tint_color (Union[List[int], Tuple[int]]): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_image_series(texture_id, bounds_min, bounds_max, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show, uv_min=uv_min, uv_max=uv_max, tint_color=tint_color)

def add_input_float(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: float =0.0, format: str ='%.3f', min_value: float =0.0, max_value: float =100.0, step: float =0.1, step_fast: float =1.0, min_clamped: bool =False, max_clamped: bool =False, on_enter: bool =False, readonly: bool =False) -> Union[int, str]:
	"""
	Adds input for floats. Step buttons can be turned on or off.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (float): 
		**format (str): 
		**min_value (float): Value for lower limit of input. By default this limits the step buttons. Use clamped to limit manual input.
		**max_value (float): Value for upper limit of input. By default this limits the step buttons. Use clamped to limit manual input.
		**step (float): Increment to change value by when the step buttons are pressed. Setting this to a value of 0 or smaller will turn off step buttons.
		**step_fast (float): After holding the step buttons for extended time the increments will switch to this value.
		**min_clamped (bool): Activates and deactivates min_value.
		**max_clamped (bool): Activates and deactivates max_value.
		**on_enter (bool): Only runs callback on enter key press.
		**readonly (bool): Activates a read only mode for the input.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_input_float(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, format=format, min_value=min_value, max_value=max_value, step=step, step_fast=step_fast, min_clamped=min_clamped, max_clamped=max_clamped, on_enter=on_enter, readonly=readonly)

def add_input_floatx(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: Union[List[float], Tuple[float]] =(0.0, 0.0, 0.0, 0.0), format: str ='%.3f', min_value: float =0.0, max_value: float =100.0, size: int =4, min_clamped: bool =False, max_clamped: bool =False, on_enter: bool =False, readonly: bool =False) -> Union[int, str]:
	"""
	Adds multi float input for up to 4 float values.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (Union[List[float], Tuple[float]]): 
		**format (str): 
		**min_value (float): Value for lower limit of input for each cell. Use clamped to turn on.
		**max_value (float): Value for upper limit of input for each cell. Use clamped to turn on.
		**size (int): Number of components.
		**min_clamped (bool): Activates and deactivates min_value.
		**max_clamped (bool): Activates and deactivates max_value.
		**on_enter (bool): Only runs callback on enter key press.
		**readonly (bool): Activates a read only mode for the inputs.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_input_floatx(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, format=format, min_value=min_value, max_value=max_value, size=size, min_clamped=min_clamped, max_clamped=max_clamped, on_enter=on_enter, readonly=readonly)

def add_input_int(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: int =0, min_value: int =0, max_value: int =100, step: int =1, step_fast: int =100, min_clamped: bool =False, max_clamped: bool =False, on_enter: bool =False, readonly: bool =False) -> Union[int, str]:
	"""
	Adds input for an int. Step buttons can be turned on or off.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (int): 
		**min_value (int): Value for lower limit of input. By default this limits the step buttons. Use clamped to limit manual input.
		**max_value (int): Value for upper limit of input. By default this limits the step buttons. Use clamped to limit manual input.
		**step (int): Increment to change value by when the step buttons are pressed. Setting this to a value of 0 or smaller will turn off step buttons.
		**step_fast (int): After holding the step buttons for extended time the increments will switch to this value.
		**min_clamped (bool): Activates and deactivates min_value.
		**max_clamped (bool): Activates and deactivates max_value.
		**on_enter (bool): Only runs callback on enter key press.
		**readonly (bool): Activates a read only mode for the input.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_input_int(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, min_value=min_value, max_value=max_value, step=step, step_fast=step_fast, min_clamped=min_clamped, max_clamped=max_clamped, on_enter=on_enter, readonly=readonly)

def add_input_intx(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: Union[List[int], Tuple[int]] =(0, 0, 0, 0), min_value: int =0, max_value: int =100, size: int =4, min_clamped: bool =False, max_clamped: bool =False, on_enter: bool =False, readonly: bool =False) -> Union[int, str]:
	"""
	Adds multi int input for up to 4 integer values.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (Union[List[int], Tuple[int]]): 
		**min_value (int): Value for lower limit of input for each cell. Use clamped to turn on.
		**max_value (int): Value for upper limit of input for each cell. Use clamped to turn on.
		**size (int): Number of components.
		**min_clamped (bool): Activates and deactivates min_value.
		**max_clamped (bool): Activates and deactivates max_value.
		**on_enter (bool): Only runs callback on enter.
		**readonly (bool): Activates a read only mode for the inputs.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_input_intx(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, min_value=min_value, max_value=max_value, size=size, min_clamped=min_clamped, max_clamped=max_clamped, on_enter=on_enter, readonly=readonly)

def add_input_text(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: str ='', hint: str ='', multiline: bool =False, no_spaces: bool =False, uppercase: bool =False, tab_input: bool =False, decimal: bool =False, hexadecimal: bool =False, readonly: bool =False, password: bool =False, scientific: bool =False, on_enter: bool =False) -> Union[int, str]:
	"""
	Adds input for text.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (str): 
		**hint (str): Displayed only when value is empty string. Will reappear if input value is set to empty string. Will not show if default value is anything other than default empty string.
		**multiline (bool): Allows for multiline text input.
		**no_spaces (bool): Filter out spaces and tabs.
		**uppercase (bool): Automatically make all inputs uppercase.
		**tab_input (bool): Allows tabs to be input instead of changing widget focus.
		**decimal (bool): Only allow 0123456789.+-*/
		**hexadecimal (bool): Only allow 0123456789ABCDEFabcdef
		**readonly (bool): Activates read only mode.
		**password (bool): Password mode, display all characters as '*'.
		**scientific (bool): Only allow 0123456789.+-*/eE (Scientific notation input)
		**on_enter (bool): Only runs callback on enter key press.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_input_text(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, hint=hint, multiline=multiline, no_spaces=no_spaces, uppercase=uppercase, tab_input=tab_input, decimal=decimal, hexadecimal=hexadecimal, readonly=readonly, password=password, scientific=scientific, on_enter=on_enter)

def add_int4_value(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, source: Union[int, str] =0, default_value: Union[List[int], Tuple[int]] =(0, 0, 0, 0), parent: Union[int, str] =internal_dpg.mvReservedUUID_3) -> Union[int, str]:
	"""
	Undocumented
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**default_value (Union[List[int], Tuple[int]]): 
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_int4_value(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, source=source, default_value=default_value, parent=parent)

def add_int_value(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, source: Union[int, str] =0, default_value: int =0, parent: Union[int, str] =internal_dpg.mvReservedUUID_3) -> Union[int, str]:
	"""
	Undocumented
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**default_value (int): 
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_int_value(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, source=source, default_value=default_value, parent=parent)

def add_key_down_handler(key : int =-1, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True, parent: Union[int, str] =internal_dpg.mvReservedUUID_1) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified key is down. Parent must be a handler registry.
	Args:
		*key (int): Submits callback for all keys
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_key_down_handler(key, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show, parent=parent)

def add_key_press_handler(key : int =-1, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True, parent: Union[int, str] =internal_dpg.mvReservedUUID_1) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified key is pressed. Parent must be a handler registry.
	Args:
		*key (int): Submits callback for all keys
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_key_press_handler(key, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show, parent=parent)

def add_key_release_handler(key : int =-1, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True, parent: Union[int, str] =internal_dpg.mvReservedUUID_1) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified key is released. Parent must be a handler registry.
	Args:
		*key (int): Submits callback for all keys
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_key_release_handler(key, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show, parent=parent)

def add_knob_float(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: float =0.0, min_value: float =0.0, max_value: float =100.0) -> Union[int, str]:
	"""
	Adds a knob that rotates based of change in x mouse position.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (float): 
		**min_value (float): Applies lower limit to value.
		**max_value (float): Applies upper limit to value.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_knob_float(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, min_value=min_value, max_value=max_value)

def add_line_series(x : Union[List[float], Tuple[float]], y : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Adds a line series to a plot.
	Args:
		x (Any): 
		y (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_line_series(x, y, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show)

def add_listbox(items : Union[List[str], Tuple[str]] =(), *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: str ='', num_items: int =3) -> Union[int, str]:
	"""
	Adds a listbox. If height is not large enought to show all items a scroll bar will appear.
	Args:
		*items (Union[List[str], Tuple[str]]): A tuple of items to be shown in the listbox. Can consist of any combination of types.
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (str): 
		**num_items (int): Expands the height of the listbox to show specified number of items.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_listbox(items, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, num_items=num_items)

def add_loading_indicator(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, pos: Union[List[int], Tuple[int]] =[], style: int =0, circle_count: int =8, speed: float =1.0, radius: float =3.0, thickness: float =1.0, color: Union[List[int], Tuple[int]] =(51, 51, 55, 255), secondary_color: Union[List[int], Tuple[int]] =(29, 151, 236, 103)) -> Union[int, str]:
	"""
	Adds a rotating anamated loding symbol.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**style (int): 0 is rotating dots style, 1 is rotating bar style.
		**circle_count (int): Number of dots show if dots or size of circle if circle.
		**speed (float): Speed the anamation will rotate.
		**radius (float): Radius size of the loading indicator.
		**thickness (float): Thickness of the circles or line.
		**color (Union[List[int], Tuple[int]]): Color of the growing center circle.
		**secondary_color (Union[List[int], Tuple[int]]): Background of the dots in dot mode.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_loading_indicator(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, show=show, pos=pos, style=style, circle_count=circle_count, speed=speed, radius=radius, thickness=thickness, color=color, secondary_color=secondary_color)

def add_menu(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5) -> Union[int, str]:
	"""
	Adds a menu to an existing menu bar. Must be followed by a call to end.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_menu(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset)

def add_menu_bar(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, show: bool =True, delay_search: bool =False) -> Union[int, str]:
	"""
	Adds a menu bar to a window.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**show (bool): Attempt to render widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_menu_bar(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, show=show, delay_search=delay_search)

def add_menu_item(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: bool =False, shortcut: str ='', check: bool =False) -> Union[int, str]:
	"""
	Adds a menu item to an existing menu. Menu items act similar to selectables.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (bool): 
		**shortcut (str): Displays text on the menu item. Typically used to show a shortcut key command.
		**check (bool): Displays a checkmark on the menu item when it is selected.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_menu_item(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, shortcut=shortcut, check=check)

def add_mouse_click_handler(button : int =-1, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True, parent: Union[int, str] =internal_dpg.mvReservedUUID_1) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified mouse button is clicked. Parent must be a handler registry.
	Args:
		*button (int): Submits callback for all mouse buttons
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_mouse_click_handler(button, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show, parent=parent)

def add_mouse_double_click_handler(button : int =-1, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True, parent: Union[int, str] =internal_dpg.mvReservedUUID_1) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified mouse button is double clicked. Parent must be a handler registry.
	Args:
		*button (int): Submits callback for all mouse buttons
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_mouse_double_click_handler(button, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show, parent=parent)

def add_mouse_down_handler(button : int =-1, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True, parent: Union[int, str] =internal_dpg.mvReservedUUID_1) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified mouse button is down. Parent must be a handler registry.
	Args:
		*button (int): Submits callback for all mouse buttons
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_mouse_down_handler(button, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show, parent=parent)

def add_mouse_drag_handler(button : int =-1, threshold : float =10.0, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True, parent: Union[int, str] =internal_dpg.mvReservedUUID_1) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified mouse button is clicked and dragged a set threshold. Parent must be a handler registry.
	Args:
		*button (int): Submits callback for all mouse buttons
		*threshold (float): The threshold the mouse must be dragged before the callback is ran
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_mouse_drag_handler(button, threshold, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show, parent=parent)

def add_mouse_move_handler(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True, parent: Union[int, str] =internal_dpg.mvReservedUUID_1) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the mouse is moved. Parent must be a handler registry.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_mouse_move_handler(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show, parent=parent)

def add_mouse_release_handler(button : int =-1, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True, parent: Union[int, str] =internal_dpg.mvReservedUUID_1) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified mouse button is released. Parent must be a handler registry.
	Args:
		*button (int): Submits callback for all mouse buttons
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_mouse_release_handler(button, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show, parent=parent)

def add_mouse_wheel_handler(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True, parent: Union[int, str] =internal_dpg.mvReservedUUID_1) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the vertical mouse wheel is scrolled. Parent must be a handler registry.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_mouse_wheel_handler(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show, parent=parent)

def add_node(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, draggable: bool =True) -> Union[int, str]:
	"""
	Adds a node to a node editor.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**draggable (bool): Allow node to be draggable.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_node(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, draggable=draggable)

def add_node_attribute(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, filter_key: str ='', tracked: bool =False, track_offset: float =0.5, attribute_type: int =0, shape: int =1, category: str ='general') -> Union[int, str]:
	"""
	Adds a node attribute.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**attribute_type (int): mvNode_Attr_Input, mvNode_Attr_Output, or mvNode_Attr_Static.
		**shape (int): Pin shape.
		**category (str): Category
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_node_attribute(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, filter_key=filter_key, tracked=tracked, track_offset=track_offset, attribute_type=attribute_type, shape=shape, category=category)

def add_node_editor(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, delink_callback: Callable =None, menubar: bool =False) -> Union[int, str]:
	"""
	Adds a node editor.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**delink_callback (Callable): Callback ran when a link is detached.
		**menubar (bool): Shows or hides the menubar.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_node_editor(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, delink_callback=delink_callback, menubar=menubar)

def add_node_link(attr_1 : Union[int, str], attr_2 : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Adds a node link between nodes.
	Args:
		attr_1 (Union[int, str]): 
		attr_2 (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_node_link(attr_1, attr_2, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, show=show)

def add_pie_series(x : float, y : float, radius : float, values : Union[List[float], Tuple[float]], labels : Union[List[str], Tuple[str]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, format: str ='%0.2f', angle: float =90.0, normalize: bool =False) -> Union[int, str]:
	"""
	Adds a pie series to a plot.
	Args:
		x (float): 
		y (float): 
		radius (float): 
		values (Any): 
		labels (Union[List[str], Tuple[str]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**format (str): 
		**angle (float): 
		**normalize (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_pie_series(x, y, radius, values, labels, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show, format=format, angle=angle, normalize=normalize)

def add_plot(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, no_title: bool =False, no_menus: bool =False, no_box_select: bool =False, no_mouse_pos: bool =False, no_highlight: bool =False, no_child: bool =False, query: bool =False, crosshairs: bool =False, anti_aliased: bool =False, equal_aspects: bool =False, pan_button: int =internal_dpg.mvMouseButton_Left, pan_mod: int =-1, fit_button: int =internal_dpg.mvMouseButton_Left, context_menu_button: int =internal_dpg.mvMouseButton_Right, box_select_button: int =internal_dpg.mvMouseButton_Right, box_select_mod: int =-1, box_select_cancel_button: int =internal_dpg.mvMouseButton_Left, query_button: int =internal_dpg.mvMouseButton_Middle, query_mod: int =-1, query_toggle_mod: int =internal_dpg.mvKey_Control, horizontal_mod: int =internal_dpg.mvKey_Alt, vertical_mod: int =internal_dpg.mvKey_Shift) -> Union[int, str]:
	"""
	Adds a plot which is used to hold series, and can be drawn to with draw commands.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**no_title (bool): 
		**no_menus (bool): 
		**no_box_select (bool): 
		**no_mouse_pos (bool): 
		**no_highlight (bool): 
		**no_child (bool): 
		**query (bool): 
		**crosshairs (bool): 
		**anti_aliased (bool): 
		**equal_aspects (bool): 
		**pan_button (int): enables panning when held
		**pan_mod (int): optional modifier that must be held for panning
		**fit_button (int): fits visible data when double clicked
		**context_menu_button (int): opens plot context menu (if enabled) when clicked
		**box_select_button (int): begins box selection when pressed and confirms selection when released
		**box_select_mod (int): begins box selection when pressed and confirms selection when released
		**box_select_cancel_button (int): cancels active box selection when pressed
		**query_button (int): begins query selection when pressed and end query selection when released
		**query_mod (int): optional modifier that must be held for query selection
		**query_toggle_mod (int): when held, active box selections turn into queries
		**horizontal_mod (int): expands active box selection/query horizontally to plot edge when held
		**vertical_mod (int): expands active box selection/query vertically to plot edge when held
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_plot(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, no_title=no_title, no_menus=no_menus, no_box_select=no_box_select, no_mouse_pos=no_mouse_pos, no_highlight=no_highlight, no_child=no_child, query=query, crosshairs=crosshairs, anti_aliased=anti_aliased, equal_aspects=equal_aspects, pan_button=pan_button, pan_mod=pan_mod, fit_button=fit_button, context_menu_button=context_menu_button, box_select_button=box_select_button, box_select_mod=box_select_mod, box_select_cancel_button=box_select_cancel_button, query_button=query_button, query_mod=query_mod, query_toggle_mod=query_toggle_mod, horizontal_mod=horizontal_mod, vertical_mod=vertical_mod)

def add_plot_annotation(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, default_value: Any =(0.0, 0.0), offset: Union[List[float], Tuple[float]] =(0.0, 0.0), color: Union[List[int], Tuple[int]] =(0, 0, 0, -255), clamped: bool =True) -> Union[int, str]:
	"""
	Adds an annotation to a plot.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**default_value (Any): 
		**offset (Union[List[float], Tuple[float]]): 
		**color (Union[List[int], Tuple[int]]): 
		**clamped (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_plot_annotation(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show, default_value=default_value, offset=offset, color=color, clamped=clamped)

def add_plot_axis(axis : int, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, no_gridlines: bool =False, no_tick_marks: bool =False, no_tick_labels: bool =False, log_scale: bool =False, invert: bool =False, lock_min: bool =False, lock_max: bool =False, time: bool =False) -> Union[int, str]:
	"""
	Adds a plot legend to a plot.
	Args:
		axis (int): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**no_gridlines (bool): 
		**no_tick_marks (bool): 
		**no_tick_labels (bool): 
		**log_scale (bool): 
		**invert (bool): 
		**lock_min (bool): 
		**lock_max (bool): 
		**time (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_plot_axis(axis, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, no_gridlines=no_gridlines, no_tick_marks=no_tick_marks, no_tick_labels=no_tick_labels, log_scale=log_scale, invert=invert, lock_min=lock_min, lock_max=lock_max, time=time)

def add_plot_legend(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, location: int =5, horizontal: bool =False, outside: bool =False) -> Union[int, str]:
	"""
	Adds a plot legend to a plot.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**location (int): location, mvPlot_Location_*
		**horizontal (bool): 
		**outside (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_plot_legend(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, location=location, horizontal=horizontal, outside=outside)

def add_progress_bar(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, overlay: str ='', default_value: float =0.0) -> Union[int, str]:
	"""
	Adds a progress bar.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**overlay (str): Overlayed text.
		**default_value (float): Normalized value to fill the bar from 0.0 to 1.0.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_progress_bar(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, overlay=overlay, default_value=default_value)

def add_radio_button(items : Union[List[str], Tuple[str]] =(), *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: str ='', horizontal: bool =False) -> Union[int, str]:
	"""
	Adds a set of radio buttons. If items keyword is empty, nothing will be shown.
	Args:
		*items (Union[List[str], Tuple[str]]): A tuple of items to be shown as radio options. Can consist of any combination of types.
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (str): 
		**horizontal (bool): Displays the radio options horizontally.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_radio_button(items, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, horizontal=horizontal)

def add_raw_texture(width : int, height : int, default_value : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, format: int =internal_dpg.mvFormat_Float_rgba, parent: Union[int, str] =internal_dpg.mvReservedUUID_2) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		width (int): 
		height (int): 
		default_value (Union[List[float], Tuple[float]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**format (int): Data format.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_raw_texture(width, height, default_value, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, format=format, parent=parent)

def add_resize_handler(parent : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified item is resized.
	Args:
		parent (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_resize_handler(parent, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show)

def add_same_line(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, xoffset: float =0.0, spacing: float =-1.0) -> Union[int, str]:
	"""
	Places a widget on the same line as the previous widget. Can also be used for horizontal spacing.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**xoffset (float): Offset from containing window.
		**spacing (float): Offset from previous widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_same_line(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, xoffset=xoffset, spacing=spacing)

def add_scatter_series(x : Union[List[float], Tuple[float]], y : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Adds a scatter series to a plot.
	Args:
		x (Any): 
		y (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_scatter_series(x, y, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show)

def add_selectable(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: bool =False, span_columns: bool =False) -> Union[int, str]:
	"""
	Adds a selectable.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (bool): 
		**span_columns (bool): Span the width of all columns if placed in a table.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_selectable(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, span_columns=span_columns)

def add_separator(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, pos: Union[List[int], Tuple[int]] =[]) -> Union[int, str]:
	"""
	Adds a horizontal line.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_separator(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, show=show, pos=pos)

def add_series_value(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, source: Union[int, str] =0, default_value: Any =(), parent: Union[int, str] =internal_dpg.mvReservedUUID_3) -> Union[int, str]:
	"""
	Undocumented
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**default_value (Any): 
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_series_value(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, source=source, default_value=default_value, parent=parent)

def add_shade_series(x : Union[List[float], Tuple[float]], y1 : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, y2: Any =[]) -> Union[int, str]:
	"""
	Adds a shade series to a plot.
	Args:
		x (Any): 
		y1 (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**y2 (Any): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_shade_series(x, y1, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show, y2=y2)

def add_simple_plot(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: Union[List[float], Tuple[float]] =(), overlay: str ='', histogram: bool =False, autosize: bool =True, min_scale: float =0.0, max_scale: float =0.0) -> Union[int, str]:
	"""
	A simple plot for visualization of a 1 dimensional set of values.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (Union[List[float], Tuple[float]]): 
		**overlay (str): overlays text (similar to a plot title)
		**histogram (bool): 
		**autosize (bool): 
		**min_scale (float): 
		**max_scale (float): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_simple_plot(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, overlay=overlay, histogram=histogram, autosize=autosize, min_scale=min_scale, max_scale=max_scale)

def add_slider_float(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: float =0.0, vertical: bool =False, no_input: bool =False, clamped: bool =False, min_value: float =0.0, max_value: float =100.0, format: str ='%.3f') -> Union[int, str]:
	"""
	Adds slider for a single float value. Directly entry can be done with double click or CTRL+Click. Min and Max alone are a soft limit for the slider. Use clamped keyword to also apply limits to the direct entry modes.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (float): 
		**vertical (bool): Sets orientation to vertical.
		**no_input (bool): Disable direct entry methods or Enter key allowing to input text directly into the widget.
		**clamped (bool): Applies the min and max limits to direct entry methods also such as double click and CTRL+Click.
		**min_value (float): Applies a limit only to sliding entry only.
		**max_value (float): Applies a limit only to sliding entry only.
		**format (str): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_slider_float(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, vertical=vertical, no_input=no_input, clamped=clamped, min_value=min_value, max_value=max_value, format=format)

def add_slider_floatx(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: Union[List[float], Tuple[float]] =(0.0, 0.0, 0.0, 0.0), size: int =4, no_input: bool =False, clamped: bool =False, min_value: float =0.0, max_value: float =100.0, format: str ='%.3f') -> Union[int, str]:
	"""
	Adds multi slider for up to 4 float values. Directly entry can be done with double click or CTRL+Click. Min and Max alone are a soft limit for the slider. Use clamped keyword to also apply limits to the direct entry modes.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (Union[List[float], Tuple[float]]): 
		**size (int): Number of components.
		**no_input (bool): Disable direct entry methods or Enter key allowing to input text directly into the widget.
		**clamped (bool): Applies the min and max limits to direct entry methods also such as double click and CTRL+Click.
		**min_value (float): Applies a limit only to sliding entry only.
		**max_value (float): Applies a limit only to sliding entry only.
		**format (str): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_slider_floatx(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, size=size, no_input=no_input, clamped=clamped, min_value=min_value, max_value=max_value, format=format)

def add_slider_int(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: int =0, vertical: bool =False, no_input: bool =False, clamped: bool =False, min_value: int =0, max_value: int =100, format: str ='%d') -> Union[int, str]:
	"""
	Adds slider for a single int value. Directly entry can be done with double click or CTRL+Click. Min and Max alone are a soft limit for the slider. Use clamped keyword to also apply limits to the direct entry modes.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (int): 
		**vertical (bool): Sets orientation to vertical.
		**no_input (bool): Disable direct entry methods or Enter key allowing to input text directly into the widget.
		**clamped (bool): Applies the min and max limits to direct entry methods also such as double click and CTRL+Click.
		**min_value (int): Applies a limit only to sliding entry only.
		**max_value (int): Applies a limit only to sliding entry only.
		**format (str): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_slider_int(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, vertical=vertical, no_input=no_input, clamped=clamped, min_value=min_value, max_value=max_value, format=format)

def add_slider_intx(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, enabled: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: Union[List[int], Tuple[int]] =(0, 0, 0, 0), size: int =4, no_input: bool =False, clamped: bool =False, min_value: int =0, max_value: int =100, format: str ='%d') -> Union[int, str]:
	"""
	Adds multi slider for up to 4 int values. CTRL+Click to directly modify the value.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**enabled (bool): Turns off functionality of widget and applies the disabled theme.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (Union[List[int], Tuple[int]]): 
		**size (int): number of components
		**no_input (bool): Disable direct entry methods or Enter key allowing to input text directly into the widget.
		**clamped (bool): Applies the min and max limits to direct entry methods also such as double click and CTRL+Click.
		**min_value (int): Applies a limit only to sliding entry only.
		**max_value (int): Applies a limit only to sliding entry only.
		**format (str): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_slider_intx(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, indent=indent, parent=parent, before=before, source=source, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, enabled=enabled, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, size=size, no_input=no_input, clamped=clamped, min_value=min_value, max_value=max_value, format=format)

def add_spacing(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, pos: Union[List[int], Tuple[int]] =[], count: int =1) -> Union[int, str]:
	"""
	Adds vertical spacing.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**count (int): Number of spacings to add the size is dependant on the curret style.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_spacing(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, show=show, pos=pos, count=count)

def add_staging_container(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_staging_container(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id)

def add_stair_series(x : Union[List[float], Tuple[float]], y : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Adds a stair series to a plot.
	Args:
		x (Any): 
		y (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_stair_series(x, y, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show)

def add_static_texture(width : int, height : int, default_value : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =internal_dpg.mvReservedUUID_2) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		width (int): 
		height (int): 
		default_value (Union[List[float], Tuple[float]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_static_texture(width, height, default_value, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent)

def add_stem_series(x : Union[List[float], Tuple[float]], y : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Adds a stem series to a plot.
	Args:
		x (Any): 
		y (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_stem_series(x, y, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, source=source, show=show)

def add_string_value(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, source: Union[int, str] =0, default_value: str ='', parent: Union[int, str] =internal_dpg.mvReservedUUID_3) -> Union[int, str]:
	"""
	Undocumented
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**default_value (str): 
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_string_value(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, source=source, default_value=default_value, parent=parent)

def add_subplots(rows : int, columns : int, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, row_ratios: Union[List[float], Tuple[float]] =[], column_ratios: Union[List[float], Tuple[float]] =[], no_title: bool =False, no_menus: bool =False, no_resize: bool =False, no_align: bool =False, link_rows: bool =False, link_columns: bool =False, link_all_x: bool =False, link_all_y: bool =False, column_major: bool =False) -> Union[int, str]:
	"""
	Adds a plot which is used to hold series, and can be drawn to with draw commands.
	Args:
		rows (int): 
		columns (int): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**row_ratios (Union[List[float], Tuple[float]]): 
		**column_ratios (Union[List[float], Tuple[float]]): 
		**no_title (bool): 
		**no_menus (bool): the user will not be able to open context menus with right-click
		**no_resize (bool): resize splitters between subplot cells will be not be provided
		**no_align (bool): subplot edges will not be aligned vertically or horizontally
		**link_rows (bool): link the y-axis limits of all plots in each row (does not apply auxiliary y-axes)
		**link_columns (bool): link the x-axis limits of all plots in each column
		**link_all_x (bool): link the x-axis limits in every plot in the subplot
		**link_all_y (bool): link the y-axis limits in every plot in the subplot (does not apply to auxiliary y-axes)
		**column_major (bool): subplots are added in column major order instead of the default row major order
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_subplots(rows, columns, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, callback=callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, row_ratios=row_ratios, column_ratios=column_ratios, no_title=no_title, no_menus=no_menus, no_resize=no_resize, no_align=no_align, link_rows=link_rows, link_columns=link_columns, link_all_x=link_all_x, link_all_y=link_all_y, column_major=column_major)

def add_tab(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, closable: bool =False, no_tooltip: bool =False, order_mode: bool =0) -> Union[int, str]:
	"""
	Adds a tab to a tab bar. Must be closed with thes end command.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**closable (bool): Creates a button on the tab that can hide the tab.
		**no_tooltip (bool): Disable tooltip for the given tab.
		**order_mode (bool): set using a constant: mvTabOrder_Reorderable: allows reordering, mvTabOrder_Fixed: fixed ordering, mvTabOrder_Leading: adds tab to front, mvTabOrder_Trailing: adds tab to back
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_tab(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, closable=closable, no_tooltip=no_tooltip, order_mode=order_mode)

def add_tab_bar(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, reorderable: bool =False) -> Union[int, str]:
	"""
	Adds a tab bar.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**reorderable (bool): Allows for the user to change the order of the tabs.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_tab_bar(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, reorderable=reorderable)

def add_tab_button(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, filter_key: str ='', tracked: bool =False, track_offset: float =0.5, no_reorder: bool =False, leading: bool =False, trailing: bool =False, no_tooltip: bool =False) -> Union[int, str]:
	"""
	Adds a tab button to a tab bar.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**no_reorder (bool): Disable reordering this tab or having another tab cross over this tab.
		**leading (bool): Enforce the tab position to the left of the tab bar (after the tab list popup button).
		**trailing (bool): Enforce the tab position to the right of the tab bar (before the scrolling buttons).
		**no_tooltip (bool): Disable tooltip for the given tab.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_tab_button(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, filter_key=filter_key, tracked=tracked, track_offset=track_offset, no_reorder=no_reorder, leading=leading, trailing=trailing, no_tooltip=no_tooltip)

def add_table(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, header_row: bool =True, inner_width: int =0, policy: int =0, freeze_rows: int =0, freeze_columns: int =0, sort_multi: bool =False, sort_tristate: bool =False, resizable: bool =False, reorderable: bool =False, hideable: bool =False, sortable: bool =False, context_menu_in_body: bool =False, row_background: bool =False, borders_innerH: bool =False, borders_outerH: bool =False, borders_innerV: bool =False, borders_outerV: bool =False, no_host_extendX: bool =False, no_host_extendY: bool =False, no_keep_columns_visible: bool =False, precise_widths: bool =False, no_clip: bool =False, pad_outerX: bool =False, no_pad_outerX: bool =False, no_pad_innerX: bool =False, scrollX: bool =False, scrollY: bool =False, no_saved_settings: bool =False) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**header_row (bool): show headers at the top of the columns
		**inner_width (int): 
		**policy (int): 
		**freeze_rows (int): 
		**freeze_columns (int): 
		**sort_multi (bool): Hold shift when clicking headers to sort on multiple column.
		**sort_tristate (bool): Allow no sorting, disable default sorting.
		**resizable (bool): Enable resizing columns
		**reorderable (bool): Enable reordering columns in header row (need calling TableSetupColumn() + TableHeadersRow() to display headers)
		**hideable (bool): Enable hiding/disabling columns in context menu.
		**sortable (bool): Enable sorting. Call TableGetSortSpecs() to obtain sort specs. Also see ImGuiTableFlags_SortMulti and ImGuiTableFlags_SortTristate.
		**context_menu_in_body (bool): Right-click on columns body/contents will display table context menu. By default it is available in TableHeadersRow().
		**row_background (bool): Set each RowBg color with ImGuiCol_TableRowBg or ImGuiCol_TableRowBgAlt (equivalent of calling TableSetBgColor with ImGuiTableBgFlags_RowBg0 on each row manually)
		**borders_innerH (bool): Draw horizontal borders between rows.
		**borders_outerH (bool): Draw horizontal borders at the top and bottom.
		**borders_innerV (bool): Draw vertical borders between columns.
		**borders_outerV (bool): Draw vertical borders on the left and right sides.
		**no_host_extendX (bool): Make outer width auto-fit to columns, overriding outer_size.x value. Only available when ScrollX/ScrollY are disabled and Stretch columns are not used.
		**no_host_extendY (bool): Make outer height stop exactly at outer_size.y (prevent auto-extending table past the limit). Only available when ScrollX/ScrollY are disabled. Data below the limit will be clipped and not visible.
		**no_keep_columns_visible (bool): Disable keeping column always minimally visible when ScrollX is off and table gets too small. Not recommended if columns are resizable.
		**precise_widths (bool): Disable distributing remainder width to stretched columns (width allocation on a 100-wide table with 3 columns: Without this flag: 33,33,34. With this flag: 33,33,33). With larger number of columns, resizing will appear to be less smooth.
		**no_clip (bool): Disable clipping rectangle for every individual columns.
		**pad_outerX (bool): Default if BordersOuterV is on. Enable outer-most padding. Generally desirable if you have headers.
		**no_pad_outerX (bool): Default if BordersOuterV is off. Disable outer-most padding.
		**no_pad_innerX (bool): Disable inner padding between columns (double inner padding if BordersOuterV is on, single inner padding if BordersOuterV is off).
		**scrollX (bool): Enable horizontal scrolling. Require 'outer_size' parameter of BeginTable() to specify the container size. Changes default sizing policy. Because this create a child window, ScrollY is currently generally recommended when using ScrollX.
		**scrollY (bool): Enable vertical scrolling.
		**no_saved_settings (bool): Never load/save settings in .ini file.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_table(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, parent=parent, before=before, source=source, callback=callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, header_row=header_row, inner_width=inner_width, policy=policy, freeze_rows=freeze_rows, freeze_columns=freeze_columns, sort_multi=sort_multi, sort_tristate=sort_tristate, resizable=resizable, reorderable=reorderable, hideable=hideable, sortable=sortable, context_menu_in_body=context_menu_in_body, row_background=row_background, borders_innerH=borders_innerH, borders_outerH=borders_outerH, borders_innerV=borders_innerV, borders_outerV=borders_outerV, no_host_extendX=no_host_extendX, no_host_extendY=no_host_extendY, no_keep_columns_visible=no_keep_columns_visible, precise_widths=precise_widths, no_clip=no_clip, pad_outerX=pad_outerX, no_pad_outerX=no_pad_outerX, no_pad_innerX=no_pad_innerX, scrollX=scrollX, scrollY=scrollY, no_saved_settings=no_saved_settings)

def add_table_column(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, init_width_or_weight: float =0.0, default_hide: bool =False, default_sort: bool =False, width_stretch: bool =False, width_fixed: bool =False, no_resize: bool =False, no_reorder: bool =False, no_hide: bool =False, no_clip: bool =False, no_sort: bool =False, no_sort_ascending: bool =False, no_sort_descending: bool =False, no_header_width: bool =False, prefer_sort_ascending: bool =True, prefer_sort_descending: bool =False, indent_enable: bool =False, indent_disable: bool =False) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**init_width_or_weight (float): 
		**default_hide (bool): Default as a hidden/disabled column.
		**default_sort (bool): Default as a sorting column.
		**width_stretch (bool): Column will stretch. Preferable with horizontal scrolling disabled (default if table sizing policy is _SizingStretchSame or _SizingStretchProp).
		**width_fixed (bool): Column will not stretch. Preferable with horizontal scrolling enabled (default if table sizing policy is _SizingFixedFit and table is resizable).
		**no_resize (bool): Disable manual resizing.
		**no_reorder (bool): Disable manual reordering this column, this will also prevent other columns from crossing over this column.
		**no_hide (bool): Disable ability to hide/disable this column.
		**no_clip (bool): Disable clipping for this column (all NoClip columns will render in a same draw command).
		**no_sort (bool): Disable ability to sort on this field (even if ImGuiTableFlags_Sortable is set on the table).
		**no_sort_ascending (bool): Disable ability to sort in the ascending direction.
		**no_sort_descending (bool): Disable ability to sort in the descending direction.
		**no_header_width (bool): Disable header text width contribution to automatic column width.
		**prefer_sort_ascending (bool): Make the initial sort direction Ascending when first sorting on this column (default).
		**prefer_sort_descending (bool): Make the initial sort direction Descending when first sorting on this column.
		**indent_enable (bool): Use current Indent value when entering cell (default for column 0).
		**indent_disable (bool): Ignore current Indent value when entering cell (default for columns > 0). Indentation changes _within_ the cell will still be honored.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_table_column(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, parent=parent, before=before, show=show, init_width_or_weight=init_width_or_weight, default_hide=default_hide, default_sort=default_sort, width_stretch=width_stretch, width_fixed=width_fixed, no_resize=no_resize, no_reorder=no_reorder, no_hide=no_hide, no_clip=no_clip, no_sort=no_sort, no_sort_ascending=no_sort_ascending, no_sort_descending=no_sort_descending, no_header_width=no_header_width, prefer_sort_ascending=prefer_sort_ascending, prefer_sort_descending=prefer_sort_descending, indent_enable=indent_enable, indent_disable=indent_disable)

def add_table_next_column(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_table_next_column(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show)

def add_table_row(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, height: int =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, filter_key: str ='') -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**height (int): Height of the item.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**filter_key (str): Used by filter widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_table_row(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, height=height, parent=parent, before=before, show=show, filter_key=filter_key)

def add_text(default_value : str ='', *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, wrap: int =-1, bullet: bool =False, color: Union[List[float], Tuple[float]] =(-1, -1, -1, -1), show_label: bool =False) -> Union[int, str]:
	"""
	Adds text. Text can have an optional label that will display to the right of the text.
	Args:
		*default_value (str): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**wrap (int): Number of pixels until wrapping starts.
		**bullet (bool): Makes the text bulleted.
		**color (Union[List[float], Tuple[float]]): Color of the text (rgba).
		**show_label (bool): Displays the label.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_text(default_value, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, source=source, show=show, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, wrap=wrap, bullet=bullet, color=color, show_label=show_label)

def add_text_point(x : float, y : float, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True, x_offset: int =..., y_offset: int =..., vertical: bool =False) -> Union[int, str]:
	"""
	Adds a labels series to a plot.
	Args:
		x (float): 
		y (float): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
		**x_offset (int): 
		**y_offset (int): 
		**vertical (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_text_point(x, y, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show, x_offset=x_offset, y_offset=y_offset, vertical=vertical)

def add_texture_registry(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, show: bool =False) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_texture_registry(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, show=show)

def add_theme(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, default_theme: bool =False) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**default_theme (bool): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_theme(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, default_theme=default_theme)

def add_theme_color(target : int =0, value : Union[List[int], Tuple[int]] =(0, 0, 0, 255), *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, category: int =0) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		*target (int): 
		*value (Union[List[int], Tuple[int]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**category (int): Options include mvThemeCat_Core, mvThemeCat_Plots, mvThemeCat_Nodes.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_theme_color(target, value, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, category=category)

def add_theme_style(target : int =0, x : float =1.0, y : float =-1.0, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, category: int =0) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		*target (int): 
		*x (float): 
		*y (float): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**category (int): Options include mvThemeCat_Core, mvThemeCat_Plots, mvThemeCat_Nodes.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_theme_style(target, x, y, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, category=category)

def add_time_picker(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', callback: Callable =None, drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', tracked: bool =False, track_offset: float =0.5, default_value: dict ={'hour': 14, 'min': 32, 'sec': 23}, hour24: bool =False) -> Union[int, str]:
	"""
	Adds a time picker.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**callback (Callable): Registers a callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_value (dict): 
		**hour24 (bool): Show 24 hour clock instead of 12 hour.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_time_picker(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, callback=callback, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, tracked=tracked, track_offset=track_offset, default_value=default_value, hour24=hour24)

def add_toggled_open_handler(parent : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified item is toggled open.
	Args:
		parent (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_toggled_open_handler(parent, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show)

def add_tooltip(parent : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Adds an advanced tool tip for an item. This command must come immediately after the item the tip is for.
	Args:
		parent (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_tooltip(parent, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, show=show)

def add_tree_node(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, before: Union[int, str] =0, payload_type: str ='$$DPG_PAYLOAD', drag_callback: Callable =None, drop_callback: Callable =None, show: bool =True, pos: Union[List[int], Tuple[int]] =[], filter_key: str ='', delay_search: bool =False, tracked: bool =False, track_offset: float =0.5, default_open: bool =False, open_on_double_click: bool =False, open_on_arrow: bool =False, leaf: bool =False, bullet: bool =False, selectable: bool =False) -> Union[int, str]:
	"""
	Adds a tree node to add items to. Must be closed with the end command.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**payload_type (str): Sender string type must be the same as the target for the target to run the payload_callback.
		**drag_callback (Callable): Registers a drag callback for drag and drop.
		**drop_callback (Callable): Registers a drop callback for drag and drop.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**tracked (bool): Scroll tracking
		**track_offset (float): 0.0f:top, 0.5f:center, 1.0f:bottom
		**default_open (bool): Sets the tree node open by default.
		**open_on_double_click (bool): Need double-click to open node.
		**open_on_arrow (bool): Only open when clicking on the arrow part.
		**leaf (bool): No collapsing, no arrow (use as a convenience for leaf nodes).
		**bullet (bool): Display a bullet instead of arrow.
		**selectable (bool): Makes the tree selectable.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_tree_node(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, before=before, payload_type=payload_type, drag_callback=drag_callback, drop_callback=drop_callback, show=show, pos=pos, filter_key=filter_key, delay_search=delay_search, tracked=tracked, track_offset=track_offset, default_open=default_open, open_on_double_click=open_on_double_click, open_on_arrow=open_on_arrow, leaf=leaf, bullet=bullet, selectable=selectable)

def add_value_registry(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0) -> Union[int, str]:
	"""
	Undocumented function
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_value_registry(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id)

def add_viewport_drawlist(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, show: bool =True, filter_key: str ='', delay_search: bool =False, front: bool =True) -> Union[int, str]:
	"""
	A container that is used to present draw items or layers directly to the viewport. By default this will draw to the back of teh viewport. Layers and draw items should be added to this widget as children.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**show (bool): Attempt to render widget.
		**filter_key (str): Used by filter widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**front (bool): Draws to the front of the view port instead of the back.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_viewport_drawlist(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, show=show, filter_key=filter_key, delay_search=delay_search, front=front)

def add_viewport_menu_bar(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, indent: int =-1, parent: Union[int, str] =0, show: bool =True, delay_search: bool =False) -> Union[int, str]:
	"""
	Adds a menu bar to the viewport.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**show (bool): Attempt to render widget.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_viewport_menu_bar(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, indent=indent, parent=parent, show=show, delay_search=delay_search)

def add_visible_handler(parent : Union[int, str], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, callback: Callable =None, show: bool =True) -> Union[int, str]:
	"""
	Adds a handler which runs a given callback when the specified item is visible.
	Args:
		parent (Union[int, str]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**callback (Callable): Registers a callback.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_visible_handler(parent, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, callback=callback, show=show)

def add_vline_series(x : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, source: Union[int, str] =0, show: bool =True) -> Union[int, str]:
	"""
	Adds a infinite vertical line series to a plot.
	Args:
		x (Any): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**source (Union[int, str]): Overrides 'id' as value storage key.
		**show (bool): Attempt to render widget.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_vline_series(x, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, source=source, show=show)

def add_window(*, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, width: int =0, height: int =0, indent: int =-1, show: bool =True, pos: Union[List[int], Tuple[int]] =[], delay_search: bool =False, min_size: Union[List[int], Tuple[int]] =[100, 100], max_size: Union[List[int], Tuple[int]] =[30000, 30000], menubar: bool =False, collapsed: bool =False, autosize: bool =False, no_resize: bool =False, no_title_bar: bool =False, no_move: bool =False, no_scrollbar: bool =False, no_collapse: bool =False, horizontal_scrollbar: bool =False, no_focus_on_appearing: bool =False, no_bring_to_front_on_focus: bool =False, no_close: bool =False, no_background: bool =False, modal: bool =False, popup: bool =False, no_saved_settings: bool =False, on_close: Callable =None) -> Union[int, str]:
	"""
	Creates a new window for following items to be added to.
	Args:
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**width (int): Width of the item.
		**height (int): Height of the item.
		**indent (int): Offsets the widget to the right the specified number multiplied by the indent style.
		**show (bool): Attempt to render widget.
		**pos (Union[List[int], Tuple[int]]): Places the item relative to window coordinates, [0,0] is top left.
		**delay_search (bool): Delays searching container for specified items until the end of the app. Possible optimization when a container has many children that are not accessed often.
		**min_size (Union[List[int], Tuple[int]]): Minimum window size.
		**max_size (Union[List[int], Tuple[int]]): Maximum window size.
		**menubar (bool): Shows or hides the menubar.
		**collapsed (bool): Collapse the window.
		**autosize (bool): Autosized the window to fit it's items.
		**no_resize (bool): Allows for the window size to be changed or fixed.
		**no_title_bar (bool): Title name for the title bar of the window.
		**no_move (bool): Allows for the window's position to be changed or fixed.
		**no_scrollbar (bool):  Disable scrollbars. (window can still scroll with mouse or programmatically)
		**no_collapse (bool): Disable user collapsing window by double-clicking on it.
		**horizontal_scrollbar (bool): Allow horizontal scrollbar to appear. (off by default)
		**no_focus_on_appearing (bool): Disable taking focus when transitioning from hidden to visible state.
		**no_bring_to_front_on_focus (bool): Disable bringing window to front when taking focus. (e.g. clicking on it or programmatically giving it focus)
		**no_close (bool): Disable user closing the window by removing the close button.
		**no_background (bool): Sets Background and border alpha to transparent.
		**modal (bool): Fills area behind window according to the theme and disables user ability to interact with anything except the window.
		**popup (bool): Fills area behind window according to the theme, removes title bar, collapse and close. Window can be closed by selecting area in the background behind the window.
		**no_saved_settings (bool): Never load/save settings in .ini file.
		**on_close (Callable): Callback ran when window is closed.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.add_window(label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, width=width, height=height, indent=indent, show=show, pos=pos, delay_search=delay_search, min_size=min_size, max_size=max_size, menubar=menubar, collapsed=collapsed, autosize=autosize, no_resize=no_resize, no_title_bar=no_title_bar, no_move=no_move, no_scrollbar=no_scrollbar, no_collapse=no_collapse, horizontal_scrollbar=horizontal_scrollbar, no_focus_on_appearing=no_focus_on_appearing, no_bring_to_front_on_focus=no_bring_to_front_on_focus, no_close=no_close, no_background=no_background, modal=modal, popup=popup, no_saved_settings=no_saved_settings, on_close=on_close)

def cleanup_dearpygui() -> None:
	"""
	Cleans up dearpygui.
	Args:
	Returns:
		None
	"""

	return internal_dpg.cleanup_dearpygui()

def clear_selected_links(node_editor : Union[int, str]) -> None:
	"""
	Undocumented
	Args:
		node_editor (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.clear_selected_links(node_editor)

def clear_selected_nodes(node_editor : Union[int, str]) -> None:
	"""
	Undocumented
	Args:
		node_editor (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.clear_selected_nodes(node_editor)

def configure_item_registry(*, allow_alias_overwrites: bool =False, manual_alias_management: bool =False) -> None:
	"""
	Undocumented
	Args:
		**allow_alias_overwrites (bool): 
		**manual_alias_management (bool): 
	Returns:
		None
	"""

	return internal_dpg.configure_item_registry(allow_alias_overwrites=allow_alias_overwrites, manual_alias_management=manual_alias_management)

def create_viewport(*, title: str ='Dear PyGui', small_icon: str ='', large_icon: str ='', width: int =1280, height: int =800, x_pos: int =100, y_pos: int =100, min_width: int =250, max_width: int =10000, min_height: int =250, max_height: int =10000, resizable: bool =True, vsync: bool =True, always_on_top: bool =False, decorated: bool =True, clear_color: Union[List[float], Tuple[float]] =(0, 0, 0, 255)) -> str:
	"""
	Creates a viewport.
	Args:
		**title (str): 
		**small_icon (str): 
		**large_icon (str): 
		**width (int): 
		**height (int): 
		**x_pos (int): 
		**y_pos (int): 
		**min_width (int): 
		**max_width (int): 
		**min_height (int): 
		**max_height (int): 
		**resizable (bool): 
		**vsync (bool): 
		**always_on_top (bool): 
		**decorated (bool): 
		**clear_color (Union[List[float], Tuple[float]]): 
	Returns:
		str
	"""

	return internal_dpg.create_viewport(title=title, small_icon=small_icon, large_icon=large_icon, width=width, height=height, x_pos=x_pos, y_pos=y_pos, min_width=min_width, max_width=max_width, min_height=min_height, max_height=max_height, resizable=resizable, vsync=vsync, always_on_top=always_on_top, decorated=decorated, clear_color=clear_color)

def delete_item(item : Union[int, str], *, children_only: bool =False, slot: int =-1) -> None:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
		**children_only (bool): 
		**slot (int): 
	Returns:
		None
	"""

	return internal_dpg.delete_item(item, children_only=children_only, slot=slot)

def does_alias_exist(alias : str) -> bool:
	"""
	Undocumented
	Args:
		alias (str): 
	Returns:
		bool
	"""

	return internal_dpg.does_alias_exist(alias)

def does_item_exist(item : Union[int, str]) -> bool:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
	Returns:
		bool
	"""

	return internal_dpg.does_item_exist(item)

def draw_arrow(p1 : Union[List[float], Tuple[float]], p2 : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, color: Union[List[int], Tuple[int]] =(255, 255, 255, 255), thickness: float =1.0, size: int =4) -> Union[int, str]:
	"""
	Draws an arrow on a drawing.
	Args:
		p1 (Union[List[float], Tuple[float]]): Arrow tip.
		p2 (Union[List[float], Tuple[float]]): Arrow tail.
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**color (Union[List[int], Tuple[int]]): 
		**thickness (float): 
		**size (int): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.draw_arrow(p1, p2, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, color=color, thickness=thickness, size=size)

def draw_bezier_cubic(p1 : Union[List[float], Tuple[float]], p2 : Union[List[float], Tuple[float]], p3 : Union[List[float], Tuple[float]], p4 : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, color: Union[List[int], Tuple[int]] =(255, 255, 255, 255), thickness: float =1.0, segments: int =0) -> Union[int, str]:
	"""
	Draws a cubic bezier curve on a drawing.
	Args:
		p1 (Union[List[float], Tuple[float]]): First point in curve.
		p2 (Union[List[float], Tuple[float]]): Second point in curve.
		p3 (Union[List[float], Tuple[float]]): Third point in curve.
		p4 (Union[List[float], Tuple[float]]): Fourth point in curve.
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**color (Union[List[int], Tuple[int]]): 
		**thickness (float): 
		**segments (int): Number of segments to approximate bezier curve.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.draw_bezier_cubic(p1, p2, p3, p4, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, color=color, thickness=thickness, segments=segments)

def draw_bezier_quadratic(p1 : Union[List[float], Tuple[float]], p2 : Union[List[float], Tuple[float]], p3 : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, color: Union[List[int], Tuple[int]] =(255, 255, 255, 255), thickness: float =1.0, segments: int =0) -> Union[int, str]:
	"""
	Draws a quadratic bezier curve on a drawing.
	Args:
		p1 (Union[List[float], Tuple[float]]): First point in curve.
		p2 (Union[List[float], Tuple[float]]): Second point in curve.
		p3 (Union[List[float], Tuple[float]]): Third point in curve.
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**color (Union[List[int], Tuple[int]]): 
		**thickness (float): 
		**segments (int): Number of segments to approximate bezier curve.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.draw_bezier_quadratic(p1, p2, p3, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, color=color, thickness=thickness, segments=segments)

def draw_circle(center : Union[List[float], Tuple[float]], radius : float, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, color: Union[List[int], Tuple[int]] =(255, 255, 255, 255), fill: Union[List[int], Tuple[int]] =(0, 0, 0, -255), thickness: float =1.0, segments: int =0) -> Union[int, str]:
	"""
	Draws a circle on a drawing.
	Args:
		center (Union[List[float], Tuple[float]]): 
		radius (float): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**color (Union[List[int], Tuple[int]]): 
		**fill (Union[List[int], Tuple[int]]): 
		**thickness (float): 
		**segments (int): Number of segments to approximate circle.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.draw_circle(center, radius, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, color=color, fill=fill, thickness=thickness, segments=segments)

def draw_ellipse(pmin : Union[List[float], Tuple[float]], pmax : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, color: Union[List[int], Tuple[int]] =(255, 255, 255, 255), fill: Union[List[int], Tuple[int]] =(0, 0, 0, -255), thickness: float =1.0, segments: int =32) -> Union[int, str]:
	"""
	Draws an ellipse on a drawing.
	Args:
		pmin (Union[List[float], Tuple[float]]): Min point of bounding rectangle.
		pmax (Union[List[float], Tuple[float]]): Max point of bounding rectangle.
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**color (Union[List[int], Tuple[int]]): 
		**fill (Union[List[int], Tuple[int]]): 
		**thickness (float): 
		**segments (int): Number of segments to approximate bezier curve.
	Returns:
		Union[int, str]
	"""

	return internal_dpg.draw_ellipse(pmin, pmax, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, color=color, fill=fill, thickness=thickness, segments=segments)

def draw_image(texture_id : Union[int, str], pmin : Union[List[float], Tuple[float]], pmax : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, uv_min: Union[List[float], Tuple[float]] =(0.0, 0.0), uv_max: Union[List[float], Tuple[float]] =(1.0, 1.0), color: Union[List[int], Tuple[int]] =(255, 255, 255, 255)) -> Union[int, str]:
	"""
	Draws an image on a drawing. p_min (top-left) and p_max (bottom-right) represent corners of the rectangle the image will be drawn to.Setting the p_min equal to the p_max will sraw the image to with 1:1 scale.uv_min and uv_max represent the normalized texture coordinates of the original image that will be shown. Using (0.0,0.0)->(1.0,1.0) texturecoordinates will generally display the entire texture.
	Args:
		texture_id (Union[int, str]): 
		pmin (Union[List[float], Tuple[float]]): Point of to start drawing texture.
		pmax (Union[List[float], Tuple[float]]): Point to complete drawing texture.
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**uv_min (Union[List[float], Tuple[float]]): Normalized coordinates on texture that will be drawn.
		**uv_max (Union[List[float], Tuple[float]]): Normalized coordinates on texture that will be drawn.
		**color (Union[List[int], Tuple[int]]): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.draw_image(texture_id, pmin, pmax, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, uv_min=uv_min, uv_max=uv_max, color=color)

def draw_line(p1 : Union[List[float], Tuple[float]], p2 : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, color: Union[List[int], Tuple[int]] =(255, 255, 255, 255), thickness: float =1.0) -> Union[int, str]:
	"""
	Draws a line on a drawing.
	Args:
		p1 (Union[List[float], Tuple[float]]): Start of line.
		p2 (Union[List[float], Tuple[float]]): End of line.
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**color (Union[List[int], Tuple[int]]): 
		**thickness (float): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.draw_line(p1, p2, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, color=color, thickness=thickness)

def draw_polygon(points : List[List[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, color: Union[List[int], Tuple[int]] =(255, 255, 255, 255), fill: Union[List[int], Tuple[int]] =(0, 0, 0, -255), thickness: float =1.0) -> Union[int, str]:
	"""
	Draws a polygon on a drawing. First and and last point should be the same to close teh polygone.
	Args:
		points (List[List[float]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**color (Union[List[int], Tuple[int]]): 
		**fill (Union[List[int], Tuple[int]]): 
		**thickness (float): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.draw_polygon(points, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, color=color, fill=fill, thickness=thickness)

def draw_polyline(points : List[List[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, closed: bool =False, color: Union[List[int], Tuple[int]] =(255, 255, 255, 255), thickness: float =1.0) -> Union[int, str]:
	"""
	Draws connected lines on a drawing from points.
	Args:
		points (List[List[float]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**closed (bool): Will close the polyline by returning to the first point.
		**color (Union[List[int], Tuple[int]]): 
		**thickness (float): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.draw_polyline(points, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, closed=closed, color=color, thickness=thickness)

def draw_quad(p1 : Union[List[float], Tuple[float]], p2 : Union[List[float], Tuple[float]], p3 : Union[List[float], Tuple[float]], p4 : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, color: Union[List[int], Tuple[int]] =(255, 255, 255, 255), fill: Union[List[int], Tuple[int]] =(0, 0, 0, -255), thickness: float =1.0) -> Union[int, str]:
	"""
	Draws a quad on a drawing.
	Args:
		p1 (Union[List[float], Tuple[float]]): 
		p2 (Union[List[float], Tuple[float]]): 
		p3 (Union[List[float], Tuple[float]]): 
		p4 (Union[List[float], Tuple[float]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**color (Union[List[int], Tuple[int]]): 
		**fill (Union[List[int], Tuple[int]]): 
		**thickness (float): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.draw_quad(p1, p2, p3, p4, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, color=color, fill=fill, thickness=thickness)

def draw_rectangle(pmin : Union[List[float], Tuple[float]], pmax : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, color: Union[List[int], Tuple[int]] =(255, 255, 255, 255), color_upper_left: Union[List[int], Tuple[int]] =(255, 255, 255, 255), color_upper_right: Union[List[int], Tuple[int]] =(255, 255, 255, 255), color_bottom_right: Union[List[int], Tuple[int]] =(255, 255, 255, 255), color_bottom_left: Union[List[int], Tuple[int]] =(255, 255, 255, 255), fill: Union[List[int], Tuple[int]] =(0, 0, 0, -255), multicolor: bool =False, rounding: float =0.0, thickness: float =1.0) -> Union[int, str]:
	"""
	Draws a rectangle on a drawing.
	Args:
		pmin (Union[List[float], Tuple[float]]): Min point of bounding rectangle.
		pmax (Union[List[float], Tuple[float]]): Max point of bounding rectangle.
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**color (Union[List[int], Tuple[int]]): 
		**color_upper_left (Union[List[int], Tuple[int]]): 'multicolor' must be set to 'True'
		**color_upper_right (Union[List[int], Tuple[int]]): 'multicolor' must be set to 'True'
		**color_bottom_right (Union[List[int], Tuple[int]]): 'multicolor' must be set to 'True'
		**color_bottom_left (Union[List[int], Tuple[int]]): 'multicolor' must be set to 'True'
		**fill (Union[List[int], Tuple[int]]): 
		**multicolor (bool): 
		**rounding (float): Number of pixels of the radius that will round the corners of the rectangle. Note: doesn't work with multicolor
		**thickness (float): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.draw_rectangle(pmin, pmax, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, color=color, color_upper_left=color_upper_left, color_upper_right=color_upper_right, color_bottom_right=color_bottom_right, color_bottom_left=color_bottom_left, fill=fill, multicolor=multicolor, rounding=rounding, thickness=thickness)

def draw_text(pos : Union[List[float], Tuple[float]], text : str, *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, color: Union[List[int], Tuple[int]] =(255, 255, 255, 255), size: float =10.0) -> Union[int, str]:
	"""
	Draws a text on a drawing.
	Args:
		pos (Union[List[float], Tuple[float]]): Top left point of bounding text rectangle.
		text (str): Text to draw.
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**color (Union[List[int], Tuple[int]]): 
		**size (float): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.draw_text(pos, text, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, color=color, size=size)

def draw_triangle(p1 : Union[List[float], Tuple[float]], p2 : Union[List[float], Tuple[float]], p3 : Union[List[float], Tuple[float]], *, label: str =None, user_data: Any =None, use_internal_label: bool =True, id: Union[int, str] =0, parent: Union[int, str] =0, before: Union[int, str] =0, show: bool =True, color: Union[List[int], Tuple[int]] =(255, 255, 255, 255), fill: Union[List[int], Tuple[int]] =(0, 0, 0, -255), thickness: float =1.0) -> Union[int, str]:
	"""
	Draws a triangle on a drawing.
	Args:
		p1 (Union[List[float], Tuple[float]]): 
		p2 (Union[List[float], Tuple[float]]): 
		p3 (Union[List[float], Tuple[float]]): 
		**label (str): Overrides 'name' as label.
		**user_data (Any): User data for callbacks.
		**use_internal_label (bool): Use generated internal label instead of user specified (appends ### uuid).
		**id (Union[int, str]): Unique id used to programmatically refer to the item.If label is unused this will be the label.
		**parent (Union[int, str]): Parent to add this item to. (runtime adding)
		**before (Union[int, str]): This item will be displayed before the specified item in the parent.
		**show (bool): Attempt to render widget.
		**color (Union[List[int], Tuple[int]]): 
		**fill (Union[List[int], Tuple[int]]): 
		**thickness (float): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.draw_triangle(p1, p2, p3, label=label, user_data=user_data, use_internal_label=use_internal_label, id=id, parent=parent, before=before, show=show, color=color, fill=fill, thickness=thickness)

def empty_container_stack() -> None:
	"""
	Undocumented
	Args:
	Returns:
		None
	"""

	return internal_dpg.empty_container_stack()

def enable_docking(*, dock_space: bool =False) -> None:
	"""
	Undocumented
	Args:
		**dock_space (bool): add explicit dockspace over viewport
	Returns:
		None
	"""

	return internal_dpg.enable_docking(dock_space=dock_space)

def fit_axis_data(axis : Union[int, str]) -> None:
	"""
	Sets the axis boundries max and min in the data series currently on the plot.
	Args:
		axis (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.fit_axis_data(axis)

def focus_item(item : Union[int, str]) -> None:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.focus_item(item)

def generate_uuid() -> Union[int, str]:
	"""
	Generate a new UUID
	Args:
	Returns:
		Union[int, str]
	"""

	return internal_dpg.generate_uuid()

def get_active_window() -> Union[int, str]:
	"""
	Undocumented
	Args:
	Returns:
		Union[int, str]
	"""

	return internal_dpg.get_active_window()

def get_alias_id(alias : str) -> Union[int, str]:
	"""
	Undocumented
	Args:
		alias (str): 
	Returns:
		Union[int, str]
	"""

	return internal_dpg.get_alias_id(alias)

def get_aliases() -> Union[List[str], Tuple[str]]:
	"""
	Undocumented
	Args:
	Returns:
		Union[List[str], Tuple[str]]
	"""

	return internal_dpg.get_aliases()

def get_all_items() -> Union[List[int], Tuple[int]]:
	"""
	Undocumented
	Args:
	Returns:
		Union[List[int], Tuple[int]]
	"""

	return internal_dpg.get_all_items()

def get_axis_limits(axis : Union[int, str]) -> Union[List[float], Tuple[float]]:
	"""
	Gets the specified axis limits.
	Args:
		axis (Union[int, str]): 
	Returns:
		Union[List[float], Tuple[float]]
	"""

	return internal_dpg.get_axis_limits(axis)

def get_colormap_color(colormap : Union[int, str], index : int) -> Union[List[int], Tuple[int]]:
	"""
	Returns a color from a colormap given an index >= 0 (modulo will be performed). This command can only be ran once the app is started.
	Args:
		colormap (Union[int, str]): 
		index (int): 
	Returns:
		Union[List[int], Tuple[int]]
	"""

	return internal_dpg.get_colormap_color(colormap, index)

def get_dearpygui_version() -> str:
	"""
	Returns the dearpygui version.
	Args:
	Returns:
		str
	"""

	return internal_dpg.get_dearpygui_version()

def get_delta_time() -> float:
	"""
	Returns time since last frame.
	Args:
	Returns:
		float
	"""

	return internal_dpg.get_delta_time()

def get_drawing_mouse_pos() -> Union[List[int], Tuple[int]]:
	"""
	Undocumented
	Args:
	Returns:
		Union[List[int], Tuple[int]]
	"""

	return internal_dpg.get_drawing_mouse_pos()

def get_file_dialog_info(file_dialog : Union[int, str]) -> dict:
	"""
	Undocumented function
	Args:
		file_dialog (Union[int, str]): 
	Returns:
		dict
	"""

	return internal_dpg.get_file_dialog_info(file_dialog)

def get_frame_count() -> int:
	"""
	Get frame count.
	Args:
	Returns:
		int
	"""

	return internal_dpg.get_frame_count()

def get_global_font_scale() -> float:
	"""
	Undocumented function
	Args:
	Returns:
		float
	"""

	return internal_dpg.get_global_font_scale()

def get_item_alias(item : Union[int, str]) -> str:
	"""
	Gets the item's alias.
	Args:
		item (Union[int, str]): 
	Returns:
		str
	"""

	return internal_dpg.get_item_alias(item)

def get_item_configuration(item : Union[int, str]) -> dict:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
	Returns:
		dict
	"""

	return internal_dpg.get_item_configuration(item)

def get_item_info(item : Union[int, str]) -> dict:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
	Returns:
		dict
	"""

	return internal_dpg.get_item_info(item)

def get_item_registry_configuration() -> dict:
	"""
	Undocumented
	Args:
	Returns:
		dict
	"""

	return internal_dpg.get_item_registry_configuration()

def get_item_state(item : Union[int, str]) -> dict:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
	Returns:
		dict
	"""

	return internal_dpg.get_item_state(item)

def get_item_types() -> dict:
	"""
	Undocumented
	Args:
	Returns:
		dict
	"""

	return internal_dpg.get_item_types()

def get_mouse_drag_delta() -> float:
	"""
	Undocumented
	Args:
	Returns:
		float
	"""

	return internal_dpg.get_mouse_drag_delta()

def get_mouse_pos(*, local: bool =True) -> Union[List[int], Tuple[int]]:
	"""
	Undocumented
	Args:
		**local (bool): 
	Returns:
		Union[List[int], Tuple[int]]
	"""

	return internal_dpg.get_mouse_pos(local=local)

def get_plot_mouse_pos() -> Union[List[int], Tuple[int]]:
	"""
	Undocumented
	Args:
	Returns:
		Union[List[int], Tuple[int]]
	"""

	return internal_dpg.get_plot_mouse_pos()

def get_plot_query_area(plot : Union[int, str]) -> Union[List[float], Tuple[float]]:
	"""
	Returns the last/current query area of the plot. (Requires plot 'query' kwarg to be enabled)
	Args:
		plot (Union[int, str]): 
	Returns:
		Union[List[float], Tuple[float]]
	"""

	return internal_dpg.get_plot_query_area(plot)

def get_selected_links(node_editor : Union[int, str]) -> List[List[str]]:
	"""
	Undocumented
	Args:
		node_editor (Union[int, str]): 
	Returns:
		List[List[str]]
	"""

	return internal_dpg.get_selected_links(node_editor)

def get_selected_nodes(node_editor : Union[int, str]) -> Union[List[int], Tuple[int]]:
	"""
	Undocumented
	Args:
		node_editor (Union[int, str]): 
	Returns:
		Union[List[int], Tuple[int]]
	"""

	return internal_dpg.get_selected_nodes(node_editor)

def get_total_time() -> float:
	"""
	Returns total time since Dear PyGui has started.
	Args:
	Returns:
		float
	"""

	return internal_dpg.get_total_time()

def get_value(item : Union[int, str]) -> Any:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
	Returns:
		Any
	"""

	return internal_dpg.get_value(item)

def get_values(items : Union[List[int], Tuple[int]]) -> Any:
	"""
	Undocumented
	Args:
		items (Union[List[int], Tuple[int]]): 
	Returns:
		Any
	"""

	return internal_dpg.get_values(items)

def get_viewport_configuration(item : Union[int, str]) -> dict:
	"""
	Returns viewport configuration.
	Args:
		item (Union[int, str]): 
	Returns:
		dict
	"""

	return internal_dpg.get_viewport_configuration(item)

def get_windows() -> Union[List[int], Tuple[int]]:
	"""
	Undocumented
	Args:
	Returns:
		Union[List[int], Tuple[int]]
	"""

	return internal_dpg.get_windows()

def get_x_scroll(item : Union[int, str]) -> float:
	"""
	Undocumented function
	Args:
		item (Union[int, str]): 
	Returns:
		float
	"""

	return internal_dpg.get_x_scroll(item)

def get_x_scroll_max(item : Union[int, str]) -> float:
	"""
	Undocumented function
	Args:
		item (Union[int, str]): 
	Returns:
		float
	"""

	return internal_dpg.get_x_scroll_max(item)

def get_y_scroll(item : Union[int, str]) -> float:
	"""
	Undocumented function
	Args:
		item (Union[int, str]): 
	Returns:
		float
	"""

	return internal_dpg.get_y_scroll(item)

def get_y_scroll_max(item : Union[int, str]) -> float:
	"""
	Undocumented function
	Args:
		item (Union[int, str]): 
	Returns:
		float
	"""

	return internal_dpg.get_y_scroll_max(item)

def is_dearpygui_running() -> bool:
	"""
	Checks if dearpygui is running.
	Args:
	Returns:
		bool
	"""

	return internal_dpg.is_dearpygui_running()

def is_key_down(key : int) -> bool:
	"""
	Undocumented
	Args:
		key (int): 
	Returns:
		bool
	"""

	return internal_dpg.is_key_down(key)

def is_key_pressed(key : int) -> bool:
	"""
	Undocumented
	Args:
		key (int): 
	Returns:
		bool
	"""

	return internal_dpg.is_key_pressed(key)

def is_key_released(key : int) -> bool:
	"""
	Undocumented
	Args:
		key (int): 
	Returns:
		bool
	"""

	return internal_dpg.is_key_released(key)

def is_mouse_button_clicked(button : int) -> bool:
	"""
	Undocumented
	Args:
		button (int): 
	Returns:
		bool
	"""

	return internal_dpg.is_mouse_button_clicked(button)

def is_mouse_button_double_clicked(button : int) -> bool:
	"""
	Undocumented
	Args:
		button (int): 
	Returns:
		bool
	"""

	return internal_dpg.is_mouse_button_double_clicked(button)

def is_mouse_button_down(button : int) -> bool:
	"""
	Undocumented
	Args:
		button (int): 
	Returns:
		bool
	"""

	return internal_dpg.is_mouse_button_down(button)

def is_mouse_button_dragging(button : int, threshold : float) -> bool:
	"""
	Undocumented
	Args:
		button (int): 
		threshold (float): 
	Returns:
		bool
	"""

	return internal_dpg.is_mouse_button_dragging(button, threshold)

def is_mouse_button_released(button : int) -> bool:
	"""
	Undocumented
	Args:
		button (int): 
	Returns:
		bool
	"""

	return internal_dpg.is_mouse_button_released(button)

def is_plot_queried(plot : Union[int, str]) -> bool:
	"""
	Returns true if the plot is currently being queried. (Requires plot 'query' kwarg to be enabled)
	Args:
		plot (Union[int, str]): 
	Returns:
		bool
	"""

	return internal_dpg.is_plot_queried(plot)

def is_viewport_created() -> bool:
	"""
	Checks if a viewport has been created.
	Args:
	Returns:
		bool
	"""

	return internal_dpg.is_viewport_created()

def last_container() -> Union[int, str]:
	"""
	Undocumented
	Args:
	Returns:
		Union[int, str]
	"""

	return internal_dpg.last_container()

def last_item() -> Union[int, str]:
	"""
	Undocumented
	Args:
	Returns:
		Union[int, str]
	"""

	return internal_dpg.last_item()

def last_root() -> Union[int, str]:
	"""
	Undocumented
	Args:
	Returns:
		Union[int, str]
	"""

	return internal_dpg.last_root()

def load_image(file : str, *, gamma: float =1.0, gamma_scale_factor: float =1.0) -> Any:
	"""
	Loads an image. Returns width, height, channels, mvBuffer
	Args:
		file (str): 
		**gamma (float): Gamma correction factor. (default is 1.0 to avoid automatic gamma correction on loading.
		**gamma_scale_factor (float): Gamma scale factor.
	Returns:
		Any
	"""

	return internal_dpg.load_image(file, gamma=gamma, gamma_scale_factor=gamma_scale_factor)

def load_init_file(file : str) -> None:
	"""
	Load dpg.ini file.
	Args:
		file (str): 
	Returns:
		None
	"""

	return internal_dpg.load_init_file(file)

def lock_mutex() -> None:
	"""
	Locks mutex
	Args:
	Returns:
		None
	"""

	return internal_dpg.lock_mutex()

def maximize_viewport() -> None:
	"""
	Maximizes the viewport.
	Args:
	Returns:
		None
	"""

	return internal_dpg.maximize_viewport()

def minimize_viewport() -> None:
	"""
	Minimizes the viewport.
	Args:
	Returns:
		None
	"""

	return internal_dpg.minimize_viewport()

def move_item(item : Union[int, str], *, parent: Union[int, str] =0, before: Union[int, str] =0) -> None:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
		**parent (Union[int, str]): 
		**before (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.move_item(item, parent=parent, before=before)

def move_item_down(item : Union[int, str]) -> None:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.move_item_down(item)

def move_item_up(item : Union[int, str]) -> None:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.move_item_up(item)

def pop_container_stack() -> Union[int, str]:
	"""
	Undocumented
	Args:
	Returns:
		Union[int, str]
	"""

	return internal_dpg.pop_container_stack()

def push_container_stack(item : Union[int, str]) -> bool:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
	Returns:
		bool
	"""

	return internal_dpg.push_container_stack(item)

def remove_alias(alias : str) -> None:
	"""
	Undocumented
	Args:
		alias (str): 
	Returns:
		None
	"""

	return internal_dpg.remove_alias(alias)

def render_dearpygui_frame() -> None:
	"""
	Renders a dearpygui frame.
	Args:
	Returns:
		None
	"""

	return internal_dpg.render_dearpygui_frame()

def reorder_items(container : Union[int, str], slot : int, new_order : Union[List[int], Tuple[int]]) -> None:
	"""
	Undocumented
	Args:
		container (Union[int, str]): 
		slot (int): 
		new_order (Union[List[int], Tuple[int]]): 
	Returns:
		None
	"""

	return internal_dpg.reorder_items(container, slot, new_order)

def reset_axis_ticks(axis : Union[int, str]) -> None:
	"""
	Removes the and manually set axis ticks and applys the default auto axis ticks.
	Args:
		axis (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.reset_axis_ticks(axis)

def reset_default_theme() -> None:
	"""
	Resets to default theme.
	Args:
	Returns:
		None
	"""

	return internal_dpg.reset_default_theme()

def reset_pos(item : Union[int, str]) -> None:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.reset_pos(item)

def sample_colormap(colormap : Union[int, str], t : float) -> Union[List[int], Tuple[int]]:
	"""
	Returns a color from a colormap given t between 0 and 1. This command can only be ran once the app is started.
	Args:
		colormap (Union[int, str]): 
		t (float): 
	Returns:
		Union[List[int], Tuple[int]]
	"""

	return internal_dpg.sample_colormap(colormap, t)

def save_init_file(file : str) -> None:
	"""
	Save dpg.ini file.
	Args:
		file (str): 
	Returns:
		None
	"""

	return internal_dpg.save_init_file(file)

def set_axis_limits(axis : Union[int, str], ymin : float, ymax : float) -> None:
	"""
	Sets limits on the axis for pan and zoom.
	Args:
		axis (Union[int, str]): 
		ymin (float): 
		ymax (float): 
	Returns:
		None
	"""

	return internal_dpg.set_axis_limits(axis, ymin, ymax)

def set_axis_limits_auto(axis : Union[int, str]) -> None:
	"""
	Removes all limits on specified axis.
	Args:
		axis (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.set_axis_limits_auto(axis)

def set_axis_ticks(axis : Union[int, str], label_pairs : Any) -> None:
	"""
	Replaces axis ticks with 'label_pairs' argument
	Args:
		axis (Union[int, str]): 
		label_pairs (Any): Tuples of label and value in the form '((label, axis_value), (label, axis_value), ...)'
	Returns:
		None
	"""

	return internal_dpg.set_axis_ticks(axis, label_pairs)

def set_colormap(item : Union[int, str], source : Union[int, str]) -> None:
	"""
	Sets the color map for widgets that accept it.
	Args:
		item (Union[int, str]): 
		source (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.set_colormap(item, source)

def set_exit_callback(callback : Callable) -> str:
	"""
	Undocumented function
	Args:
		callback (Callable): 
	Returns:
		str
	"""

	return internal_dpg.set_exit_callback(callback)

def set_global_font_scale(scale : float) -> None:
	"""
	Undocumented function
	Args:
		scale (float): 
	Returns:
		None
	"""

	return internal_dpg.set_global_font_scale(scale)

def set_init_file(*, file: str ='dpg.ini') -> None:
	"""
	set dpg.ini file.
	Args:
		**file (str): dpg.ini by default
	Returns:
		None
	"""

	return internal_dpg.set_init_file(file=file)

def set_item_alias(item : Union[int, str], alias : str) -> None:
	"""
	Sets the item's alias.
	Args:
		item (Union[int, str]): 
		alias (str): 
	Returns:
		None
	"""

	return internal_dpg.set_item_alias(item, alias)

def set_item_children(item : Union[int, str], source : Union[int, str], slot : int) -> dict:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
		source (Union[int, str]): 
		slot (int): 
	Returns:
		dict
	"""

	return internal_dpg.set_item_children(item, source, slot)

def set_item_disabled_theme(item : Union[int, str], theme : Union[int, str]) -> None:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
		theme (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.set_item_disabled_theme(item, theme)

def set_item_font(item : Union[int, str], font : Union[int, str]) -> None:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
		font (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.set_item_font(item, font)

def set_item_theme(item : Union[int, str], theme : Union[int, str]) -> None:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
		theme (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.set_item_theme(item, theme)

def set_item_type_disabled_theme(item : int, theme : Union[int, str]) -> None:
	"""
	Undocumented
	Args:
		item (int): 
		theme (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.set_item_type_disabled_theme(item, theme)

def set_item_type_theme(item : int, theme : Union[int, str]) -> None:
	"""
	Undocumented
	Args:
		item (int): 
		theme (Union[int, str]): 
	Returns:
		None
	"""

	return internal_dpg.set_item_type_theme(item, theme)

def set_primary_window(window : Union[int, str], value : bool) -> None:
	"""
	Undocumented
	Args:
		window (Union[int, str]): 
		value (bool): 
	Returns:
		None
	"""

	return internal_dpg.set_primary_window(window, value)

def set_staging_mode(mode : bool) -> None:
	"""
	Undocumented
	Args:
		mode (bool): 
	Returns:
		None
	"""

	return internal_dpg.set_staging_mode(mode)

def set_start_callback(callback : Callable) -> str:
	"""
	Undocumented function
	Args:
		callback (Callable): 
	Returns:
		str
	"""

	return internal_dpg.set_start_callback(callback)

def set_value(item : Union[int, str], value : Any) -> None:
	"""
	Undocumented
	Args:
		item (Union[int, str]): 
		value (Any): 
	Returns:
		None
	"""

	return internal_dpg.set_value(item, value)

def set_viewport_resize_callback(callback : Callable) -> str:
	"""
	Undocumented function
	Args:
		callback (Callable): 
	Returns:
		str
	"""

	return internal_dpg.set_viewport_resize_callback(callback)

def set_x_scroll(item : Union[int, str], value : float) -> None:
	"""
	Undocumented function
	Args:
		item (Union[int, str]): 
		value (float): 
	Returns:
		None
	"""

	return internal_dpg.set_x_scroll(item, value)

def set_y_scroll(item : Union[int, str], value : float) -> None:
	"""
	Undocumented function
	Args:
		item (Union[int, str]): 
		value (float): 
	Returns:
		None
	"""

	return internal_dpg.set_y_scroll(item, value)

def setup_dearpygui(*, viewport: str ='') -> None:
	"""
	Sets up dearpygui
	Args:
		**viewport (str): 
	Returns:
		None
	"""

	return internal_dpg.setup_dearpygui(viewport=viewport)

def show_imgui_demo() -> None:
	"""
	Undocumented
	Args:
	Returns:
		None
	"""

	return internal_dpg.show_imgui_demo()

def show_implot_demo() -> None:
	"""
	Undocumented
	Args:
	Returns:
		None
	"""

	return internal_dpg.show_implot_demo()

def show_tool(tool : Union[int, str]) -> str:
	"""
	Undocumented function
	Args:
		tool (Union[int, str]): 
	Returns:
		str
	"""

	return internal_dpg.show_tool(tool)

def show_viewport(viewport : str, *, minimized: bool =False, maximized: bool =False) -> None:
	"""
	Shows the viewport
	Args:
		viewport (str): 
		**minimized (bool): 
		**maximized (bool): 
	Returns:
		None
	"""

	return internal_dpg.show_viewport(viewport, minimized=minimized, maximized=maximized)

def split_frame(*, delay: int =32) -> None:
	"""
	Waits one frame.
	Args:
		**delay (int): Minimal delay in in milliseconds
	Returns:
		None
	"""

	return internal_dpg.split_frame(delay=delay)

def stage_items(items : Union[List[int], Tuple[int]]) -> None:
	"""
	Undocumented
	Args:
		items (Union[List[int], Tuple[int]]): 
	Returns:
		None
	"""

	return internal_dpg.stage_items(items)

def stop_dearpygui() -> None:
	"""
	Stops dearpygui.
	Args:
	Returns:
		None
	"""

	return internal_dpg.stop_dearpygui()

def top_container_stack() -> Union[int, str]:
	"""
	Undocumented
	Args:
	Returns:
		Union[int, str]
	"""

	return internal_dpg.top_container_stack()

def unlock_mutex() -> None:
	"""
	Unlocks mutex
	Args:
	Returns:
		None
	"""

	return internal_dpg.unlock_mutex()

def unstage_items(items : Union[List[int], Tuple[int]]) -> None:
	"""
	Undocumented
	Args:
		items (Union[List[int], Tuple[int]]): 
	Returns:
		None
	"""

	return internal_dpg.unstage_items(items)


##########################################################
# Constants #
##########################################################

mvMouseButton_Left=internal_dpg.mvMouseButton_Left
mvMouseButton_Right=internal_dpg.mvMouseButton_Right
mvMouseButton_Middle=internal_dpg.mvMouseButton_Middle
mvMouseButton_X1=internal_dpg.mvMouseButton_X1
mvMouseButton_X2=internal_dpg.mvMouseButton_X2
mvKey_0=internal_dpg.mvKey_0
mvKey_1=internal_dpg.mvKey_1
mvKey_2=internal_dpg.mvKey_2
mvKey_3=internal_dpg.mvKey_3
mvKey_4=internal_dpg.mvKey_4
mvKey_5=internal_dpg.mvKey_5
mvKey_6=internal_dpg.mvKey_6
mvKey_7=internal_dpg.mvKey_7
mvKey_8=internal_dpg.mvKey_8
mvKey_9=internal_dpg.mvKey_9
mvKey_A=internal_dpg.mvKey_A
mvKey_B=internal_dpg.mvKey_B
mvKey_C=internal_dpg.mvKey_C
mvKey_D=internal_dpg.mvKey_D
mvKey_E=internal_dpg.mvKey_E
mvKey_F=internal_dpg.mvKey_F
mvKey_G=internal_dpg.mvKey_G
mvKey_H=internal_dpg.mvKey_H
mvKey_I=internal_dpg.mvKey_I
mvKey_J=internal_dpg.mvKey_J
mvKey_K=internal_dpg.mvKey_K
mvKey_L=internal_dpg.mvKey_L
mvKey_M=internal_dpg.mvKey_M
mvKey_N=internal_dpg.mvKey_N
mvKey_O=internal_dpg.mvKey_O
mvKey_P=internal_dpg.mvKey_P
mvKey_Q=internal_dpg.mvKey_Q
mvKey_R=internal_dpg.mvKey_R
mvKey_S=internal_dpg.mvKey_S
mvKey_T=internal_dpg.mvKey_T
mvKey_U=internal_dpg.mvKey_U
mvKey_V=internal_dpg.mvKey_V
mvKey_W=internal_dpg.mvKey_W
mvKey_X=internal_dpg.mvKey_X
mvKey_Y=internal_dpg.mvKey_Y
mvKey_Z=internal_dpg.mvKey_Z
mvKey_Back=internal_dpg.mvKey_Back
mvKey_Tab=internal_dpg.mvKey_Tab
mvKey_Clear=internal_dpg.mvKey_Clear
mvKey_Return=internal_dpg.mvKey_Return
mvKey_Shift=internal_dpg.mvKey_Shift
mvKey_Control=internal_dpg.mvKey_Control
mvKey_Alt=internal_dpg.mvKey_Alt
mvKey_Pause=internal_dpg.mvKey_Pause
mvKey_Capital=internal_dpg.mvKey_Capital
mvKey_Escape=internal_dpg.mvKey_Escape
mvKey_Spacebar=internal_dpg.mvKey_Spacebar
mvKey_Prior=internal_dpg.mvKey_Prior
mvKey_Next=internal_dpg.mvKey_Next
mvKey_End=internal_dpg.mvKey_End
mvKey_Home=internal_dpg.mvKey_Home
mvKey_Left=internal_dpg.mvKey_Left
mvKey_Up=internal_dpg.mvKey_Up
mvKey_Right=internal_dpg.mvKey_Right
mvKey_Down=internal_dpg.mvKey_Down
mvKey_Select=internal_dpg.mvKey_Select
mvKey_Print=internal_dpg.mvKey_Print
mvKey_Execute=internal_dpg.mvKey_Execute
mvKey_PrintScreen=internal_dpg.mvKey_PrintScreen
mvKey_Insert=internal_dpg.mvKey_Insert
mvKey_Delete=internal_dpg.mvKey_Delete
mvKey_Help=internal_dpg.mvKey_Help
mvKey_LWin=internal_dpg.mvKey_LWin
mvKey_RWin=internal_dpg.mvKey_RWin
mvKey_Apps=internal_dpg.mvKey_Apps
mvKey_Sleep=internal_dpg.mvKey_Sleep
mvKey_NumPad0=internal_dpg.mvKey_NumPad0
mvKey_NumPad1=internal_dpg.mvKey_NumPad1
mvKey_NumPad2=internal_dpg.mvKey_NumPad2
mvKey_NumPad3=internal_dpg.mvKey_NumPad3
mvKey_NumPad4=internal_dpg.mvKey_NumPad4
mvKey_NumPad5=internal_dpg.mvKey_NumPad5
mvKey_NumPad6=internal_dpg.mvKey_NumPad6
mvKey_NumPad7=internal_dpg.mvKey_NumPad7
mvKey_NumPad8=internal_dpg.mvKey_NumPad8
mvKey_NumPad9=internal_dpg.mvKey_NumPad9
mvKey_Multiply=internal_dpg.mvKey_Multiply
mvKey_Add=internal_dpg.mvKey_Add
mvKey_Separator=internal_dpg.mvKey_Separator
mvKey_Subtract=internal_dpg.mvKey_Subtract
mvKey_Decimal=internal_dpg.mvKey_Decimal
mvKey_Divide=internal_dpg.mvKey_Divide
mvKey_F1=internal_dpg.mvKey_F1
mvKey_F2=internal_dpg.mvKey_F2
mvKey_F3=internal_dpg.mvKey_F3
mvKey_F4=internal_dpg.mvKey_F4
mvKey_F5=internal_dpg.mvKey_F5
mvKey_F6=internal_dpg.mvKey_F6
mvKey_F7=internal_dpg.mvKey_F7
mvKey_F8=internal_dpg.mvKey_F8
mvKey_F9=internal_dpg.mvKey_F9
mvKey_F10=internal_dpg.mvKey_F10
mvKey_F11=internal_dpg.mvKey_F11
mvKey_F12=internal_dpg.mvKey_F12
mvKey_F13=internal_dpg.mvKey_F13
mvKey_F14=internal_dpg.mvKey_F14
mvKey_F15=internal_dpg.mvKey_F15
mvKey_F16=internal_dpg.mvKey_F16
mvKey_F17=internal_dpg.mvKey_F17
mvKey_F18=internal_dpg.mvKey_F18
mvKey_F19=internal_dpg.mvKey_F19
mvKey_F20=internal_dpg.mvKey_F20
mvKey_F21=internal_dpg.mvKey_F21
mvKey_F22=internal_dpg.mvKey_F22
mvKey_F23=internal_dpg.mvKey_F23
mvKey_F24=internal_dpg.mvKey_F24
mvKey_NumLock=internal_dpg.mvKey_NumLock
mvKey_ScrollLock=internal_dpg.mvKey_ScrollLock
mvKey_LShift=internal_dpg.mvKey_LShift
mvKey_RShift=internal_dpg.mvKey_RShift
mvKey_LControl=internal_dpg.mvKey_LControl
mvKey_RControl=internal_dpg.mvKey_RControl
mvKey_LMenu=internal_dpg.mvKey_LMenu
mvKey_RMenu=internal_dpg.mvKey_RMenu
mvKey_Browser_Back=internal_dpg.mvKey_Browser_Back
mvKey_Browser_Forward=internal_dpg.mvKey_Browser_Forward
mvKey_Browser_Refresh=internal_dpg.mvKey_Browser_Refresh
mvKey_Browser_Stop=internal_dpg.mvKey_Browser_Stop
mvKey_Browser_Search=internal_dpg.mvKey_Browser_Search
mvKey_Browser_Favorites=internal_dpg.mvKey_Browser_Favorites
mvKey_Browser_Home=internal_dpg.mvKey_Browser_Home
mvKey_Volume_Mute=internal_dpg.mvKey_Volume_Mute
mvKey_Volume_Down=internal_dpg.mvKey_Volume_Down
mvKey_Volume_Up=internal_dpg.mvKey_Volume_Up
mvKey_Media_Next_Track=internal_dpg.mvKey_Media_Next_Track
mvKey_Media_Prev_Track=internal_dpg.mvKey_Media_Prev_Track
mvKey_Media_Stop=internal_dpg.mvKey_Media_Stop
mvKey_Media_Play_Pause=internal_dpg.mvKey_Media_Play_Pause
mvKey_Launch_Mail=internal_dpg.mvKey_Launch_Mail
mvKey_Launch_Media_Select=internal_dpg.mvKey_Launch_Media_Select
mvKey_Launch_App1=internal_dpg.mvKey_Launch_App1
mvKey_Launch_App2=internal_dpg.mvKey_Launch_App2
mvKey_Colon=internal_dpg.mvKey_Colon
mvKey_Plus=internal_dpg.mvKey_Plus
mvKey_Comma=internal_dpg.mvKey_Comma
mvKey_Minus=internal_dpg.mvKey_Minus
mvKey_Period=internal_dpg.mvKey_Period
mvKey_Slash=internal_dpg.mvKey_Slash
mvKey_Tilde=internal_dpg.mvKey_Tilde
mvKey_Open_Brace=internal_dpg.mvKey_Open_Brace
mvKey_Backslash=internal_dpg.mvKey_Backslash
mvKey_Close_Brace=internal_dpg.mvKey_Close_Brace
mvKey_Quote=internal_dpg.mvKey_Quote
mvSpacing=internal_dpg.mvSpacing
mvSameLine=internal_dpg.mvSameLine
mvInputText=internal_dpg.mvInputText
mvButton=internal_dpg.mvButton
mvTool_About=internal_dpg.mvTool_About
mvTool_Debug=internal_dpg.mvTool_Debug
mvTool_Doc=internal_dpg.mvTool_Doc
mvTool_ItemRegistry=internal_dpg.mvTool_ItemRegistry
mvTool_Metrics=internal_dpg.mvTool_Metrics
mvTool_Style=internal_dpg.mvTool_Style
mvTool_Font=internal_dpg.mvTool_Font
mvFontAtlas=internal_dpg.mvFontAtlas
mvAppUUID=internal_dpg.mvAppUUID
mvInvalidUUID=internal_dpg.mvInvalidUUID
mvDir_None=internal_dpg.mvDir_None
mvDir_Left=internal_dpg.mvDir_Left
mvDir_Right=internal_dpg.mvDir_Right
mvDir_Up=internal_dpg.mvDir_Up
mvDir_Down=internal_dpg.mvDir_Down
mvRadioButton=internal_dpg.mvRadioButton
mvTabBar=internal_dpg.mvTabBar
mvTab=internal_dpg.mvTab
mvTabOrder_Reorderable=internal_dpg.mvTabOrder_Reorderable
mvTabOrder_Fixed=internal_dpg.mvTabOrder_Fixed
mvTabOrder_Leading=internal_dpg.mvTabOrder_Leading
mvTabOrder_Trailing=internal_dpg.mvTabOrder_Trailing
mvImage=internal_dpg.mvImage
mvMenuBar=internal_dpg.mvMenuBar
mvViewportMenuBar=internal_dpg.mvViewportMenuBar
mvMenu=internal_dpg.mvMenu
mvMenuItem=internal_dpg.mvMenuItem
mvGroup=internal_dpg.mvGroup
mvChild=internal_dpg.mvChild
mvSliderFloat=internal_dpg.mvSliderFloat
mvSliderInt=internal_dpg.mvSliderInt
mvFilterSet=internal_dpg.mvFilterSet
mvDragFloat=internal_dpg.mvDragFloat
mvDragInt=internal_dpg.mvDragInt
mvInputFloat=internal_dpg.mvInputFloat
mvInputInt=internal_dpg.mvInputInt
mvColorEdit=internal_dpg.mvColorEdit
mvColorEdit_AlphaPreviewNone=internal_dpg.mvColorEdit_AlphaPreviewNone
mvColorEdit_AlphaPreview=internal_dpg.mvColorEdit_AlphaPreview
mvColorEdit_AlphaPreviewHalf=internal_dpg.mvColorEdit_AlphaPreviewHalf
mvColorEdit_uint8=internal_dpg.mvColorEdit_uint8
mvColorEdit_float=internal_dpg.mvColorEdit_float
mvColorEdit_rgb=internal_dpg.mvColorEdit_rgb
mvColorEdit_hsv=internal_dpg.mvColorEdit_hsv
mvColorEdit_hex=internal_dpg.mvColorEdit_hex
mvColorEdit_input_rgb=internal_dpg.mvColorEdit_input_rgb
mvColorEdit_input_hsv=internal_dpg.mvColorEdit_input_hsv
mvClipper=internal_dpg.mvClipper
mvColorPicker=internal_dpg.mvColorPicker
mvColorPicker_bar=internal_dpg.mvColorPicker_bar
mvColorPicker_wheel=internal_dpg.mvColorPicker_wheel
mvTooltip=internal_dpg.mvTooltip
mvCollapsingHeader=internal_dpg.mvCollapsingHeader
mvSeparator=internal_dpg.mvSeparator
mvCheckbox=internal_dpg.mvCheckbox
mvListbox=internal_dpg.mvListbox
mvText=internal_dpg.mvText
mvCombo=internal_dpg.mvCombo
mvComboHeight_Small=internal_dpg.mvComboHeight_Small
mvComboHeight_Regular=internal_dpg.mvComboHeight_Regular
mvComboHeight_Large=internal_dpg.mvComboHeight_Large
mvComboHeight_Largest=internal_dpg.mvComboHeight_Largest
mvPlot=internal_dpg.mvPlot
mvPlotMarker_None=internal_dpg.mvPlotMarker_None
mvPlotMarker_Circle=internal_dpg.mvPlotMarker_Circle
mvPlotMarker_Square=internal_dpg.mvPlotMarker_Square
mvPlotMarker_Diamond=internal_dpg.mvPlotMarker_Diamond
mvPlotMarker_Up=internal_dpg.mvPlotMarker_Up
mvPlotMarker_Down=internal_dpg.mvPlotMarker_Down
mvPlotMarker_Left=internal_dpg.mvPlotMarker_Left
mvPlotMarker_Right=internal_dpg.mvPlotMarker_Right
mvPlotMarker_Cross=internal_dpg.mvPlotMarker_Cross
mvPlotMarker_Plus=internal_dpg.mvPlotMarker_Plus
mvPlotMarker_Asterisk=internal_dpg.mvPlotMarker_Asterisk
mvSimplePlot=internal_dpg.mvSimplePlot
mvDrawlist=internal_dpg.mvDrawlist
mvWindowAppItem=internal_dpg.mvWindowAppItem
mvSelectable=internal_dpg.mvSelectable
mvTreeNode=internal_dpg.mvTreeNode
mvProgressBar=internal_dpg.mvProgressBar
mvDummy=internal_dpg.mvDummy
mvImageButton=internal_dpg.mvImageButton
mvTimePicker=internal_dpg.mvTimePicker
mvDatePicker=internal_dpg.mvDatePicker
mvDatePickerLevel_Day=internal_dpg.mvDatePickerLevel_Day
mvDatePickerLevel_Month=internal_dpg.mvDatePickerLevel_Month
mvDatePickerLevel_Year=internal_dpg.mvDatePickerLevel_Year
mvColorButton=internal_dpg.mvColorButton
mvFileDialog=internal_dpg.mvFileDialog
mvTabButton=internal_dpg.mvTabButton
mvNodeEditor=internal_dpg.mvNodeEditor
mvNode=internal_dpg.mvNode
mvNodeAttribute=internal_dpg.mvNodeAttribute
mvNode_PinShape_Circle=internal_dpg.mvNode_PinShape_Circle
mvNode_PinShape_CircleFilled=internal_dpg.mvNode_PinShape_CircleFilled
mvNode_PinShape_Triangle=internal_dpg.mvNode_PinShape_Triangle
mvNode_PinShape_TriangleFilled=internal_dpg.mvNode_PinShape_TriangleFilled
mvNode_PinShape_Quad=internal_dpg.mvNode_PinShape_Quad
mvNode_PinShape_QuadFilled=internal_dpg.mvNode_PinShape_QuadFilled
mvNode_Attr_Input=internal_dpg.mvNode_Attr_Input
mvNode_Attr_Output=internal_dpg.mvNode_Attr_Output
mvNode_Attr_Static=internal_dpg.mvNode_Attr_Static
mvTable=internal_dpg.mvTable
mvTable_SizingFixedFit=internal_dpg.mvTable_SizingFixedFit
mvTable_SizingFixedSame=internal_dpg.mvTable_SizingFixedSame
mvTable_SizingStretchProp=internal_dpg.mvTable_SizingStretchProp
mvTable_SizingStretchSame=internal_dpg.mvTable_SizingStretchSame
mvTableColumn=internal_dpg.mvTableColumn
mvTableNextColumn=internal_dpg.mvTableNextColumn
mvTableRow=internal_dpg.mvTableRow
mvDrawLine=internal_dpg.mvDrawLine
mvDrawArrow=internal_dpg.mvDrawArrow
mvDrawTriangle=internal_dpg.mvDrawTriangle
mvDrawCircle=internal_dpg.mvDrawCircle
mvDrawEllipse=internal_dpg.mvDrawEllipse
mvDrawBezierCubic=internal_dpg.mvDrawBezierCubic
mvDrawBezierQuadratic=internal_dpg.mvDrawBezierQuadratic
mvDrawQuad=internal_dpg.mvDrawQuad
mvDrawRect=internal_dpg.mvDrawRect
mvDrawText=internal_dpg.mvDrawText
mvDrawPolygon=internal_dpg.mvDrawPolygon
mvDrawPolyline=internal_dpg.mvDrawPolyline
mvDrawImage=internal_dpg.mvDrawImage
mvDragFloatMulti=internal_dpg.mvDragFloatMulti
mvDragIntMulti=internal_dpg.mvDragIntMulti
mvSliderFloatMulti=internal_dpg.mvSliderFloatMulti
mvSliderIntMulti=internal_dpg.mvSliderIntMulti
mvInputIntMulti=internal_dpg.mvInputIntMulti
mvInputFloatMulti=internal_dpg.mvInputFloatMulti
mvDragPoint=internal_dpg.mvDragPoint
mvDragLine=internal_dpg.mvDragLine
mvAnnotation=internal_dpg.mvAnnotation
mvLineSeries=internal_dpg.mvLineSeries
mvScatterSeries=internal_dpg.mvScatterSeries
mvStemSeries=internal_dpg.mvStemSeries
mvStairSeries=internal_dpg.mvStairSeries
mvBarSeries=internal_dpg.mvBarSeries
mvErrorSeries=internal_dpg.mvErrorSeries
mvVLineSeries=internal_dpg.mvVLineSeries
mvHLineSeries=internal_dpg.mvHLineSeries
mvHeatSeries=internal_dpg.mvHeatSeries
mvImageSeries=internal_dpg.mvImageSeries
mvPieSeries=internal_dpg.mvPieSeries
mvShadeSeries=internal_dpg.mvShadeSeries
mvLabelSeries=internal_dpg.mvLabelSeries
mvHistogramSeries=internal_dpg.mvHistogramSeries
mvPlotBin_Sqrt=internal_dpg.mvPlotBin_Sqrt
mvPlotBin_Sturges=internal_dpg.mvPlotBin_Sturges
mvPlotBin_Rice=internal_dpg.mvPlotBin_Rice
mvPlotBin_Scott=internal_dpg.mvPlotBin_Scott
mv2dHistogramSeries=internal_dpg.mv2dHistogramSeries
mvCandleSeries=internal_dpg.mvCandleSeries
mvAreaSeries=internal_dpg.mvAreaSeries
mvColorMapScale=internal_dpg.mvColorMapScale
mvSlider3D=internal_dpg.mvSlider3D
mvKnobFloat=internal_dpg.mvKnobFloat
mvLoadingIndicator=internal_dpg.mvLoadingIndicator
mvNodeLink=internal_dpg.mvNodeLink
mvTextureRegistry=internal_dpg.mvTextureRegistry
mvStaticTexture=internal_dpg.mvStaticTexture
mvDynamicTexture=internal_dpg.mvDynamicTexture
mvStagingContainer=internal_dpg.mvStagingContainer
mvDrawLayer=internal_dpg.mvDrawLayer
mvViewportDrawlist=internal_dpg.mvViewportDrawlist
mvFileExtension=internal_dpg.mvFileExtension
mvPlotLegend=internal_dpg.mvPlotLegend
mvPlot_Location_Center=internal_dpg.mvPlot_Location_Center
mvPlot_Location_North=internal_dpg.mvPlot_Location_North
mvPlot_Location_South=internal_dpg.mvPlot_Location_South
mvPlot_Location_West=internal_dpg.mvPlot_Location_West
mvPlot_Location_East=internal_dpg.mvPlot_Location_East
mvPlot_Location_NorthWest=internal_dpg.mvPlot_Location_NorthWest
mvPlot_Location_NorthEast=internal_dpg.mvPlot_Location_NorthEast
mvPlot_Location_SouthWest=internal_dpg.mvPlot_Location_SouthWest
mvPlot_Location_SouthEast=internal_dpg.mvPlot_Location_SouthEast
mvPlotAxis=internal_dpg.mvPlotAxis
mvXAxis=internal_dpg.mvXAxis
mvYAxis=internal_dpg.mvYAxis
mvHandlerRegistry=internal_dpg.mvHandlerRegistry
mvKeyDownHandler=internal_dpg.mvKeyDownHandler
mvKeyPressHandler=internal_dpg.mvKeyPressHandler
mvKeyReleaseHandler=internal_dpg.mvKeyReleaseHandler
mvMouseMoveHandler=internal_dpg.mvMouseMoveHandler
mvMouseWheelHandler=internal_dpg.mvMouseWheelHandler
mvMouseClickHandler=internal_dpg.mvMouseClickHandler
mvMouseDoubleClickHandler=internal_dpg.mvMouseDoubleClickHandler
mvMouseDownHandler=internal_dpg.mvMouseDownHandler
mvMouseReleaseHandler=internal_dpg.mvMouseReleaseHandler
mvMouseDragHandler=internal_dpg.mvMouseDragHandler
mvHoverHandler=internal_dpg.mvHoverHandler
mvActiveHandler=internal_dpg.mvActiveHandler
mvFocusHandler=internal_dpg.mvFocusHandler
mvVisibleHandler=internal_dpg.mvVisibleHandler
mvEditedHandler=internal_dpg.mvEditedHandler
mvActivatedHandler=internal_dpg.mvActivatedHandler
mvDeactivatedHandler=internal_dpg.mvDeactivatedHandler
mvDeactivatedAfterEditHandler=internal_dpg.mvDeactivatedAfterEditHandler
mvToggledOpenHandler=internal_dpg.mvToggledOpenHandler
mvClickedHandler=internal_dpg.mvClickedHandler
mvDragPayload=internal_dpg.mvDragPayload
mvResizeHandler=internal_dpg.mvResizeHandler
mvFont=internal_dpg.mvFont
mvFontRegistry=internal_dpg.mvFontRegistry
mvTheme=internal_dpg.mvTheme
mvThemeCat_Core=internal_dpg.mvThemeCat_Core
mvThemeCat_Plots=internal_dpg.mvThemeCat_Plots
mvThemeCat_Nodes=internal_dpg.mvThemeCat_Nodes
mvThemeColor=internal_dpg.mvThemeColor
mvThemeCol_Text=internal_dpg.mvThemeCol_Text
mvThemeCol_TextDisabled=internal_dpg.mvThemeCol_TextDisabled
mvThemeCol_WindowBg=internal_dpg.mvThemeCol_WindowBg
mvThemeCol_ChildBg=internal_dpg.mvThemeCol_ChildBg
mvThemeCol_Border=internal_dpg.mvThemeCol_Border
mvThemeCol_PopupBg=internal_dpg.mvThemeCol_PopupBg
mvThemeCol_BorderShadow=internal_dpg.mvThemeCol_BorderShadow
mvThemeCol_FrameBg=internal_dpg.mvThemeCol_FrameBg
mvThemeCol_FrameBgHovered=internal_dpg.mvThemeCol_FrameBgHovered
mvThemeCol_FrameBgActive=internal_dpg.mvThemeCol_FrameBgActive
mvThemeCol_TitleBg=internal_dpg.mvThemeCol_TitleBg
mvThemeCol_TitleBgActive=internal_dpg.mvThemeCol_TitleBgActive
mvThemeCol_TitleBgCollapsed=internal_dpg.mvThemeCol_TitleBgCollapsed
mvThemeCol_MenuBarBg=internal_dpg.mvThemeCol_MenuBarBg
mvThemeCol_ScrollbarBg=internal_dpg.mvThemeCol_ScrollbarBg
mvThemeCol_ScrollbarGrab=internal_dpg.mvThemeCol_ScrollbarGrab
mvThemeCol_ScrollbarGrabHovered=internal_dpg.mvThemeCol_ScrollbarGrabHovered
mvThemeCol_ScrollbarGrabActive=internal_dpg.mvThemeCol_ScrollbarGrabActive
mvThemeCol_CheckMark=internal_dpg.mvThemeCol_CheckMark
mvThemeCol_SliderGrab=internal_dpg.mvThemeCol_SliderGrab
mvThemeCol_SliderGrabActive=internal_dpg.mvThemeCol_SliderGrabActive
mvThemeCol_Button=internal_dpg.mvThemeCol_Button
mvThemeCol_ButtonHovered=internal_dpg.mvThemeCol_ButtonHovered
mvThemeCol_ButtonActive=internal_dpg.mvThemeCol_ButtonActive
mvThemeCol_Header=internal_dpg.mvThemeCol_Header
mvThemeCol_HeaderHovered=internal_dpg.mvThemeCol_HeaderHovered
mvThemeCol_HeaderActive=internal_dpg.mvThemeCol_HeaderActive
mvThemeCol_Separator=internal_dpg.mvThemeCol_Separator
mvThemeCol_SeparatorHovered=internal_dpg.mvThemeCol_SeparatorHovered
mvThemeCol_SeparatorActive=internal_dpg.mvThemeCol_SeparatorActive
mvThemeCol_ResizeGrip=internal_dpg.mvThemeCol_ResizeGrip
mvThemeCol_ResizeGripHovered=internal_dpg.mvThemeCol_ResizeGripHovered
mvThemeCol_ResizeGripActive=internal_dpg.mvThemeCol_ResizeGripActive
mvThemeCol_Tab=internal_dpg.mvThemeCol_Tab
mvThemeCol_TabHovered=internal_dpg.mvThemeCol_TabHovered
mvThemeCol_TabActive=internal_dpg.mvThemeCol_TabActive
mvThemeCol_TabUnfocused=internal_dpg.mvThemeCol_TabUnfocused
mvThemeCol_TabUnfocusedActive=internal_dpg.mvThemeCol_TabUnfocusedActive
mvThemeCol_DockingPreview=internal_dpg.mvThemeCol_DockingPreview
mvThemeCol_DockingEmptyBg=internal_dpg.mvThemeCol_DockingEmptyBg
mvThemeCol_PlotLines=internal_dpg.mvThemeCol_PlotLines
mvThemeCol_PlotLinesHovered=internal_dpg.mvThemeCol_PlotLinesHovered
mvThemeCol_PlotHistogram=internal_dpg.mvThemeCol_PlotHistogram
mvThemeCol_PlotHistogramHovered=internal_dpg.mvThemeCol_PlotHistogramHovered
mvThemeCol_TableHeaderBg=internal_dpg.mvThemeCol_TableHeaderBg
mvThemeCol_TableBorderStrong=internal_dpg.mvThemeCol_TableBorderStrong
mvThemeCol_TableBorderLight=internal_dpg.mvThemeCol_TableBorderLight
mvThemeCol_TableRowBg=internal_dpg.mvThemeCol_TableRowBg
mvThemeCol_TableRowBgAlt=internal_dpg.mvThemeCol_TableRowBgAlt
mvThemeCol_TextSelectedBg=internal_dpg.mvThemeCol_TextSelectedBg
mvThemeCol_DragDropTarget=internal_dpg.mvThemeCol_DragDropTarget
mvThemeCol_NavHighlight=internal_dpg.mvThemeCol_NavHighlight
mvThemeCol_NavWindowingHighlight=internal_dpg.mvThemeCol_NavWindowingHighlight
mvThemeCol_NavWindowingDimBg=internal_dpg.mvThemeCol_NavWindowingDimBg
mvThemeCol_ModalWindowDimBg=internal_dpg.mvThemeCol_ModalWindowDimBg
mvPlotCol_Line=internal_dpg.mvPlotCol_Line
mvPlotCol_Fill=internal_dpg.mvPlotCol_Fill
mvPlotCol_MarkerOutline=internal_dpg.mvPlotCol_MarkerOutline
mvPlotCol_MarkerFill=internal_dpg.mvPlotCol_MarkerFill
mvPlotCol_ErrorBar=internal_dpg.mvPlotCol_ErrorBar
mvPlotCol_FrameBg=internal_dpg.mvPlotCol_FrameBg
mvPlotCol_PlotBg=internal_dpg.mvPlotCol_PlotBg
mvPlotCol_PlotBorder=internal_dpg.mvPlotCol_PlotBorder
mvPlotCol_LegendBg=internal_dpg.mvPlotCol_LegendBg
mvPlotCol_LegendBorder=internal_dpg.mvPlotCol_LegendBorder
mvPlotCol_LegendText=internal_dpg.mvPlotCol_LegendText
mvPlotCol_TitleText=internal_dpg.mvPlotCol_TitleText
mvPlotCol_InlayText=internal_dpg.mvPlotCol_InlayText
mvPlotCol_XAxis=internal_dpg.mvPlotCol_XAxis
mvPlotCol_XAxisGrid=internal_dpg.mvPlotCol_XAxisGrid
mvPlotCol_YAxis=internal_dpg.mvPlotCol_YAxis
mvPlotCol_YAxisGrid=internal_dpg.mvPlotCol_YAxisGrid
mvPlotCol_YAxis2=internal_dpg.mvPlotCol_YAxis2
mvPlotCol_YAxisGrid2=internal_dpg.mvPlotCol_YAxisGrid2
mvPlotCol_YAxis3=internal_dpg.mvPlotCol_YAxis3
mvPlotCol_YAxisGrid3=internal_dpg.mvPlotCol_YAxisGrid3
mvPlotCol_Selection=internal_dpg.mvPlotCol_Selection
mvPlotCol_Query=internal_dpg.mvPlotCol_Query
mvPlotCol_Crosshairs=internal_dpg.mvPlotCol_Crosshairs
mvNodeCol_NodeBackground=internal_dpg.mvNodeCol_NodeBackground
mvNodeCol_NodeBackgroundHovered=internal_dpg.mvNodeCol_NodeBackgroundHovered
mvNodeCol_NodeBackgroundSelected=internal_dpg.mvNodeCol_NodeBackgroundSelected
mvNodeCol_NodeOutline=internal_dpg.mvNodeCol_NodeOutline
mvNodeCol_TitleBar=internal_dpg.mvNodeCol_TitleBar
mvNodeCol_TitleBarHovered=internal_dpg.mvNodeCol_TitleBarHovered
mvNodeCol_TitleBarSelected=internal_dpg.mvNodeCol_TitleBarSelected
mvNodeCol_Link=internal_dpg.mvNodeCol_Link
mvNodeCol_LinkHovered=internal_dpg.mvNodeCol_LinkHovered
mvNodeCol_LinkSelected=internal_dpg.mvNodeCol_LinkSelected
mvNodeCol_Pin=internal_dpg.mvNodeCol_Pin
mvNodeCol_PinHovered=internal_dpg.mvNodeCol_PinHovered
mvNodeCol_BoxSelector=internal_dpg.mvNodeCol_BoxSelector
mvNodeCol_BoxSelectorOutline=internal_dpg.mvNodeCol_BoxSelectorOutline
mvNodeCol_GridBackground=internal_dpg.mvNodeCol_GridBackground
mvNodeCol_GridLine=internal_dpg.mvNodeCol_GridLine
mvThemeStyle=internal_dpg.mvThemeStyle
mvStyleVar_Alpha=internal_dpg.mvStyleVar_Alpha
mvStyleVar_WindowPadding=internal_dpg.mvStyleVar_WindowPadding
mvStyleVar_WindowRounding=internal_dpg.mvStyleVar_WindowRounding
mvStyleVar_WindowBorderSize=internal_dpg.mvStyleVar_WindowBorderSize
mvStyleVar_WindowMinSize=internal_dpg.mvStyleVar_WindowMinSize
mvStyleVar_WindowTitleAlign=internal_dpg.mvStyleVar_WindowTitleAlign
mvStyleVar_ChildRounding=internal_dpg.mvStyleVar_ChildRounding
mvStyleVar_ChildBorderSize=internal_dpg.mvStyleVar_ChildBorderSize
mvStyleVar_PopupRounding=internal_dpg.mvStyleVar_PopupRounding
mvStyleVar_PopupBorderSize=internal_dpg.mvStyleVar_PopupBorderSize
mvStyleVar_FramePadding=internal_dpg.mvStyleVar_FramePadding
mvStyleVar_FrameRounding=internal_dpg.mvStyleVar_FrameRounding
mvStyleVar_FrameBorderSize=internal_dpg.mvStyleVar_FrameBorderSize
mvStyleVar_ItemSpacing=internal_dpg.mvStyleVar_ItemSpacing
mvStyleVar_ItemInnerSpacing=internal_dpg.mvStyleVar_ItemInnerSpacing
mvStyleVar_IndentSpacing=internal_dpg.mvStyleVar_IndentSpacing
mvStyleVar_CellPadding=internal_dpg.mvStyleVar_CellPadding
mvStyleVar_ScrollbarSize=internal_dpg.mvStyleVar_ScrollbarSize
mvStyleVar_ScrollbarRounding=internal_dpg.mvStyleVar_ScrollbarRounding
mvStyleVar_GrabMinSize=internal_dpg.mvStyleVar_GrabMinSize
mvStyleVar_GrabRounding=internal_dpg.mvStyleVar_GrabRounding
mvStyleVar_TabRounding=internal_dpg.mvStyleVar_TabRounding
mvStyleVar_ButtonTextAlign=internal_dpg.mvStyleVar_ButtonTextAlign
mvStyleVar_SelectableTextAlign=internal_dpg.mvStyleVar_SelectableTextAlign
mvPlotStyleVar_LineWeight=internal_dpg.mvPlotStyleVar_LineWeight
mvPlotStyleVar_Marker=internal_dpg.mvPlotStyleVar_Marker
mvPlotStyleVar_MarkerSize=internal_dpg.mvPlotStyleVar_MarkerSize
mvPlotStyleVar_MarkerWeight=internal_dpg.mvPlotStyleVar_MarkerWeight
mvPlotStyleVar_FillAlpha=internal_dpg.mvPlotStyleVar_FillAlpha
mvPlotStyleVar_ErrorBarSize=internal_dpg.mvPlotStyleVar_ErrorBarSize
mvPlotStyleVar_ErrorBarWeight=internal_dpg.mvPlotStyleVar_ErrorBarWeight
mvPlotStyleVar_DigitalBitHeight=internal_dpg.mvPlotStyleVar_DigitalBitHeight
mvPlotStyleVar_DigitalBitGap=internal_dpg.mvPlotStyleVar_DigitalBitGap
mvPlotStyleVar_PlotBorderSize=internal_dpg.mvPlotStyleVar_PlotBorderSize
mvPlotStyleVar_MinorAlpha=internal_dpg.mvPlotStyleVar_MinorAlpha
mvPlotStyleVar_MajorTickLen=internal_dpg.mvPlotStyleVar_MajorTickLen
mvPlotStyleVar_MinorTickLen=internal_dpg.mvPlotStyleVar_MinorTickLen
mvPlotStyleVar_MajorTickSize=internal_dpg.mvPlotStyleVar_MajorTickSize
mvPlotStyleVar_MinorTickSize=internal_dpg.mvPlotStyleVar_MinorTickSize
mvPlotStyleVar_MajorGridSize=internal_dpg.mvPlotStyleVar_MajorGridSize
mvPlotStyleVar_MinorGridSize=internal_dpg.mvPlotStyleVar_MinorGridSize
mvPlotStyleVar_PlotPadding=internal_dpg.mvPlotStyleVar_PlotPadding
mvPlotStyleVar_LabelPadding=internal_dpg.mvPlotStyleVar_LabelPadding
mvPlotStyleVar_LegendPadding=internal_dpg.mvPlotStyleVar_LegendPadding
mvPlotStyleVar_LegendInnerPadding=internal_dpg.mvPlotStyleVar_LegendInnerPadding
mvPlotStyleVar_LegendSpacing=internal_dpg.mvPlotStyleVar_LegendSpacing
mvPlotStyleVar_MousePosPadding=internal_dpg.mvPlotStyleVar_MousePosPadding
mvPlotStyleVar_AnnotationPadding=internal_dpg.mvPlotStyleVar_AnnotationPadding
mvPlotStyleVar_FitPadding=internal_dpg.mvPlotStyleVar_FitPadding
mvPlotStyleVar_PlotDefaultSize=internal_dpg.mvPlotStyleVar_PlotDefaultSize
mvPlotStyleVar_PlotMinSize=internal_dpg.mvPlotStyleVar_PlotMinSize
mvNodeStyleVar_GridSpacing=internal_dpg.mvNodeStyleVar_GridSpacing
mvNodeStyleVar_NodeCornerRounding=internal_dpg.mvNodeStyleVar_NodeCornerRounding
mvNodeStyleVar_NodePaddingHorizontal=internal_dpg.mvNodeStyleVar_NodePaddingHorizontal
mvNodeStyleVar_NodePaddingVertical=internal_dpg.mvNodeStyleVar_NodePaddingVertical
mvNodeStyleVar_NodeBorderThickness=internal_dpg.mvNodeStyleVar_NodeBorderThickness
mvNodeStyleVar_LinkThickness=internal_dpg.mvNodeStyleVar_LinkThickness
mvNodeStyleVar_LinkLineSegmentsPerLength=internal_dpg.mvNodeStyleVar_LinkLineSegmentsPerLength
mvNodeStyleVar_LinkHoverDistance=internal_dpg.mvNodeStyleVar_LinkHoverDistance
mvNodeStyleVar_PinCircleRadius=internal_dpg.mvNodeStyleVar_PinCircleRadius
mvNodeStyleVar_PinQuadSideLength=internal_dpg.mvNodeStyleVar_PinQuadSideLength
mvNodeStyleVar_PinTriangleSideLength=internal_dpg.mvNodeStyleVar_PinTriangleSideLength
mvNodeStyleVar_PinLineThickness=internal_dpg.mvNodeStyleVar_PinLineThickness
mvNodeStyleVar_PinHoverRadius=internal_dpg.mvNodeStyleVar_PinHoverRadius
mvNodeStyleVar_PinOffset=internal_dpg.mvNodeStyleVar_PinOffset
mvFontRangeHint=internal_dpg.mvFontRangeHint
mvFontRangeHint_Default=internal_dpg.mvFontRangeHint_Default
mvFontRangeHint_Japanese=internal_dpg.mvFontRangeHint_Japanese
mvFontRangeHint_Korean=internal_dpg.mvFontRangeHint_Korean
mvFontRangeHint_Chinese_Full=internal_dpg.mvFontRangeHint_Chinese_Full
mvFontRangeHint_Chinese_Simplified_Common=internal_dpg.mvFontRangeHint_Chinese_Simplified_Common
mvFontRangeHint_Cyrillic=internal_dpg.mvFontRangeHint_Cyrillic
mvFontRangeHint_Thai=internal_dpg.mvFontRangeHint_Thai
mvFontRangeHint_Vietnamese=internal_dpg.mvFontRangeHint_Vietnamese
mvFontRange=internal_dpg.mvFontRange
mvFontChars=internal_dpg.mvFontChars
mvCharRemap=internal_dpg.mvCharRemap
mvValueRegistry=internal_dpg.mvValueRegistry
mvIntValue=internal_dpg.mvIntValue
mvFloatValue=internal_dpg.mvFloatValue
mvFloat4Value=internal_dpg.mvFloat4Value
mvInt4Value=internal_dpg.mvInt4Value
mvBoolValue=internal_dpg.mvBoolValue
mvStringValue=internal_dpg.mvStringValue
mvDoubleValue=internal_dpg.mvDoubleValue
mvDouble4Value=internal_dpg.mvDouble4Value
mvColorValue=internal_dpg.mvColorValue
mvFloatVectValue=internal_dpg.mvFloatVectValue
mvSeriesValue=internal_dpg.mvSeriesValue
mvRawTexture=internal_dpg.mvRawTexture
mvFormat_Float_rgba=internal_dpg.mvFormat_Float_rgba
mvFormat_Float_rgb=internal_dpg.mvFormat_Float_rgb
mvSubPlots=internal_dpg.mvSubPlots
mvColorMap=internal_dpg.mvColorMap
mvPlotColormap_Default=internal_dpg.mvPlotColormap_Default
mvPlotColormap_Deep=internal_dpg.mvPlotColormap_Deep
mvPlotColormap_Dark=internal_dpg.mvPlotColormap_Dark
mvPlotColormap_Pastel=internal_dpg.mvPlotColormap_Pastel
mvPlotColormap_Paired=internal_dpg.mvPlotColormap_Paired
mvPlotColormap_Viridis=internal_dpg.mvPlotColormap_Viridis
mvPlotColormap_Plasma=internal_dpg.mvPlotColormap_Plasma
mvPlotColormap_Hot=internal_dpg.mvPlotColormap_Hot
mvPlotColormap_Cool=internal_dpg.mvPlotColormap_Cool
mvPlotColormap_Pink=internal_dpg.mvPlotColormap_Pink
mvPlotColormap_Jet=internal_dpg.mvPlotColormap_Jet
mvPlotColormap_Twilight=internal_dpg.mvPlotColormap_Twilight
mvPlotColormap_RdBu=internal_dpg.mvPlotColormap_RdBu
mvPlotColormap_BrBG=internal_dpg.mvPlotColormap_BrBG
mvPlotColormap_PiYG=internal_dpg.mvPlotColormap_PiYG
mvPlotColormap_Spectral=internal_dpg.mvPlotColormap_Spectral
mvPlotColormap_Greys=internal_dpg.mvPlotColormap_Greys
mvColorMapRegistry=internal_dpg.mvColorMapRegistry
mvColorMapButton=internal_dpg.mvColorMapButton
mvColorMapSlider=internal_dpg.mvColorMapSlider
mvReservedUUID_0=internal_dpg.mvReservedUUID_0
mvReservedUUID_1=internal_dpg.mvReservedUUID_1
mvReservedUUID_2=internal_dpg.mvReservedUUID_2
mvReservedUUID_3=internal_dpg.mvReservedUUID_3
mvReservedUUID_4=internal_dpg.mvReservedUUID_4
mvReservedUUID_5=internal_dpg.mvReservedUUID_5
mvReservedUUID_6=internal_dpg.mvReservedUUID_6
mvReservedUUID_7=internal_dpg.mvReservedUUID_7
mvReservedUUID_8=internal_dpg.mvReservedUUID_8
mvReservedUUID_9=internal_dpg.mvReservedUUID_9
